@@ -6,7 +6,6 @@ import gtcache
 import config
 import prefs
 import gtk.glade
-import resource
 import platformutils
 
 ###############################################################################
@@ -37,10 +36,6 @@ class Application:
         # For overriding
         pass
 
-    # This is called on OS X when we are handling a click on an RSS feed
-    # button for Safari. NEEDS: add code here to register as a RSS feed
-    # reader on Windows too. Just call this function when we're launched
-    # to handle a click on a feed.
     def addAndSelectFeed(self, url):
         # For overriding
         pass
