@@ -9,7 +9,7 @@ import gconf
 import platformutils
 from gtcache import gettext as _
 
-import resource
+import resources
 from frontend import *
 from frontend_implementation import UIBackendDelegate
 from frontend_implementation.gtk_queue import gtkAsyncMethod, gtkSyncMethod
@@ -109,13 +109,21 @@ class MainFrame:
         self.isFullscreen = False
         self.aboutWidget = None
         self.currentVideoFilename = None
-        self._gtkInit()
+
+        import views, util, indexes
+        engines = []
+        for engine in views.searchEngines:
+            engines.append((engine.name, engine.title))
+        searchFeed = util.getSingletonDDBObject (views.feeds.filterWithIndex(indexes.feedsByURL, 'dtv:search'))
+        default_engine = searchFeed.lastEngine
+
+        self._gtkInit(engines, default_engine)
 
     @gtkAsyncMethod
-    def _gtkInit(self):
+    def _gtkInit(self, engines, default_engine):
         # Create the widget tree, and remember important widgets
         platformutils.confirmMainThread()
-        self.widgetTree = WidgetTree(resource.path('democracy.glade'), 'main-window', 'democracyplayer')
+        self.widgetTree = WidgetTree(resources.path('democracy.glade'), 'main-window', 'democracyplayer')
         self.displayBoxes = {
             self.mainDisplay : self.widgetTree['main-box'],
             self.channelsDisplay : self.widgetTree['channels-box'],
@@ -124,7 +132,7 @@ class MainFrame:
 
         UIBackendDelegate.dialogParent = self.widgetTree['main-window']
 
-        self.widgetTree['main-window'].set_icon_from_file (resource.sharePath('pixmaps/democracyplayer-128x128.png'))
+        self.widgetTree['main-window'].set_icon_from_file (resources.sharePath('pixmaps/democracyplayer-128x128.png'))
 
         # create the buttonsDown attribute to the video time scale.  It will
         # track which mouse buttons are currently pressed.  This is usefull
@@ -151,13 +159,26 @@ class MainFrame:
             self.uiManager.insert_action_group (actionGroup, i)
             i = i + 1
 
-        self.uiManager.add_ui_from_file(resource.path('Democracy.xml'))
+        self.uiManager.add_ui_from_file(resources.path('Democracy.xml'))
 
         self.widgetTree['menubar-box'].add (self.uiManager.get_widget('/menubar'))
         self.widgetTree['main-window'].add_accel_group(self.uiManager.get_accel_group())
 
         self.widgetTree['volume-scale'].set_value (config.get(prefs.VOLUME_LEVEL))
 
+        store = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
+        select_iter = None
+        for name, title in engines:
+            iter = store.append((name, title))
+            if select_iter is None or default_engine == name:
+                select_iter = iter
+        cell = gtk.CellRendererText()
+        combo = self.widgetTree["combobox-chrome-search-engine"]
+        combo.pack_start(cell, True)
+        combo.add_attribute(cell, 'text', 1)
+        combo.set_model (store)
+        combo.set_active_iter(select_iter)
+
         self.windowChanger = MainWindowChanger(self.widgetTree, self,
                 MainWindowChanger.BROWSING)
 
@@ -263,7 +284,11 @@ class MainFrame:
             def delete_event_cb(widget, event):
                 widget.hide()
                 return True
+            def response_cb(widget, id):
+                widget.hide()
+                return True
             self.aboutWidget.connect ("delete_event", delete_event_cb)
+            self.aboutWidget.connect ("response", response_cb)
             self.aboutWidget.set_transient_for (self.widgetTree['main-window'])
         self.aboutWidget.present()
 
