@@ -5,6 +5,7 @@ import gtk
 import gtk.gdk
 import gnomevfs
 import gconf
+import sys
 from gtk_queue import gtkAsyncMethod, gtkSyncMethod
 from platformcfg import gconf_lock
 
@@ -41,8 +42,8 @@ class VideoDisplay (app.VideoDisplayBase):
             renderer.setWidget(self.widget)
             self.renderers.append(renderer)
             print "loaded renderer '%s'" % modname
-        except ImportError, error:
-            print "initRenderers: couldn't load %s: %s" % (modname, error)
+        except:
+            print "initRenderers: couldn't load %s: %s" % (modname, sys.exc_info()[1])
 
     @gtkAsyncMethod
     def initRenderers(self):
@@ -50,7 +51,7 @@ class VideoDisplay (app.VideoDisplayBase):
         gconf_lock.acquire()
         values = gconf.client_get_default().get("/apps/democracy/player/renderers")
         if values == None:
-#            self.add_renderer("gstrenderer")
+            self.add_renderer("gstrenderer")
             self.add_renderer("xinerenderer")
         else:
             for value in values.get_list():
