@@ -9,7 +9,7 @@ import shutil
 import frontend
 import config
 import prefs
-import resource
+import resources
 import MainFrame
 import singleclick
 import eventloop
@@ -18,6 +18,7 @@ import dialogs
 import folder
 import playlist
 import platformutils
+import startup
 from gtcache import gettext as _
  
 def AttachBoolean (widget, descriptor, sensitive_widget = None):
@@ -352,21 +353,24 @@ class CallbackHandler(object):
         folder.createNewChannelFolder()
 
     def on_preference(self, event = None):
+        import autodler
         # get our add channel dialog
         movie_dir = config.get(prefs.MOVIES_DIRECTORY)
         if config.get(prefs.PRESERVE_DISK_SPACE):
             old_disk = config.get(prefs.PRESERVE_X_GB_FREE)
         else:
             old_disk = 0
-        widgetTree = MainFrame.WidgetTree(resource.path('democracy.glade'), 'dialog-preferences', 'democracyplayer')
+        widgetTree = MainFrame.WidgetTree(resources.path('democracy.glade'), 'dialog-preferences', 'democracyplayer')
         dialog = widgetTree['dialog-preferences']
         mainWindow = self.mainFrame.widgetTree['main-window']
         dialog.set_transient_for(mainWindow)
         AttachBoolean (widgetTree['checkbutton-limit'], prefs.LIMIT_UPSTREAM, widgetTree['spinbutton-limit'])
         AttachBoolean (widgetTree['checkbutton-padding'], prefs.PRESERVE_DISK_SPACE, widgetTree['spinbutton-padding'])
+        AttachBoolean (widgetTree['checkbutton-autorun'], prefs.RUN_DTV_AT_STARTUP)
         AttachInteger (widgetTree['spinbutton-limit'], prefs.UPSTREAM_LIMIT_IN_KBS)
         AttachInteger (widgetTree['spinbutton-bt-min-port'], prefs.BT_MIN_PORT)
         AttachInteger (widgetTree['spinbutton-bt-max-port'], prefs.BT_MAX_PORT)
+        AttachInteger (widgetTree['spinbutton-max-manual'], prefs.MAX_MANUAL_DOWNLOADS)
         AttachFloat(widgetTree['spinbutton-padding'], prefs.PRESERVE_X_GB_FREE)
         AttachCombo (widgetTree['combobox-poll'], prefs.CHECK_CHANNELS_EVERY_X_MN, (30, 60, -1))
         AttachCombo (widgetTree['combobox-expiration'], prefs.EXPIRE_AFTER_X_DAYS, (1, 3, 6, 10, 30, -1))
@@ -380,20 +384,21 @@ class CallbackHandler(object):
         chooser.set_filename (movie_dir + "/")
         # run the dialog
         response = dialog.run()
+        autodler.updatePrefs()
         new_movie_dir = widgetTree['filechooserbutton-movies-directory'].get_filename()
         if (movie_dir != new_movie_dir):
             print "NEW: %r" % new_movie_dir
-            migrate_widgetTree = MainFrame.WidgetTree(resource.path('democracy.glade'), 'dialog-migrate', 'democracyplater')
+            migrate_widgetTree = MainFrame.WidgetTree(resources.path('democracy.glade'), 'dialog-migrate', 'democracyplater')
             migrate_dialog = migrate_widgetTree['dialog-migrate']
             response = migrate_dialog.run()
             app.changeMoviesDirectory(new_movie_dir, 
                     response == gtk.RESPONSE_YES)
 
             migrate_dialog.destroy()
-
+        dialog.destroy()
         if config.get(prefs.BT_MAX_PORT) < config.get(prefs.BT_MIN_PORT):
             config.set(prefs.BT_MAX_PORT, config.get(prefs.BT_MIN_PORT))
-        dialog.destroy()
+        startup.updateAutostart()
         if config.get(prefs.PRESERVE_DISK_SPACE):
             new_disk = config.get(prefs.PRESERVE_X_GB_FREE)
         else:
@@ -406,5 +411,12 @@ class CallbackHandler(object):
         print "Donate unimplemented"
 
     def on_delete(self, event = None):
-            eventloop.addUrgentCall(app.controller.removeCurrentSelection, 
-                    "remove current selection")
+        eventloop.addUrgentCall(app.controller.removeCurrentSelection, 
+                "remove current selection")
+
+    def on_button_chrome_search_go_clicked (self, event=None):
+        widgetTree = self.mainFrame.widgetTree
+        term = widgetTree["entry-chrome-search-term"].get_text()
+        iter = widgetTree["combobox-chrome-search-engine"].get_active_iter()
+        (engine,) = widgetTree["combobox-chrome-search-engine"].get_model().get(iter, 0)
+        eventloop.addIdle (lambda:app.controller.performSearch (engine, term), "Search for %s on %s" % (term, engine))
