@@ -52,11 +52,25 @@ def launchDemocracy():
 
 # =============================================================================
 
-def launchDownloaderDaemon():
+def getModulePath(name):
     import imp
-    mfile, daemonPath, mdesc = imp.find_module('dl_daemon')
+    mfile, mpath, mdesc = imp.find_module(name)
+    if mfile is not None:
+        mfile.close()
+    return mpath
+
+def launchDownloaderDaemon():
+    # Increase the maximum file descriptor count (to the max)
+    import resource
+    print "DTV: Increasing file descriptor count limit in Downloader."
+    resource.setrlimit(resource.RLIMIT_NOFILE, (-1,-1))
+
+    # Insert the downloader private module path
+    daemonPath = getModulePath('dl_daemon')
     daemonPrivatePath = os.path.join(daemonPath, 'private')
     sys.path[0:0] = [daemonPath, daemonPrivatePath]
+    
+    # And launch
     import Democracy_Downloader
     Democracy_Downloader.launch()
 
