@@ -39,7 +39,16 @@ class PlaybackController (app.PlaybackControllerBase):
     def playItemExternally(self, itemID):
         item = app.PlaybackControllerBase.playItemExternally(self, itemID)
         moviePath = item.getVideoFilename()
-        ok = NSWorkspace.sharedWorkspace().openFile_withApplication_andDeactivate_(moviePath, nil, YES)
+
+        ws = NSWorkspace.sharedWorkspace()
+        ok, externalApp, movieType = ws.getInfoForFile_application_type_(moviePath)
+        if ok:
+            if externalApp == NSBundle.mainBundle().bundlePath():
+                print 'DTV: WARNING, trying to play movie externally with Democracy.'
+                ok = False
+            else:
+                ok = ws.openFile_withApplication_andDeactivate_(moviePath, nil, YES)
+
         if not ok:
             print "DTV: movie %s could not be externally opened" % moviePath
 
@@ -118,6 +127,8 @@ class VideoDisplayController (NibClassBuilder.AutoBaseClass):
         VideoDisplayController._instance = self
         self.forwardButton.setCell_(SkipSeekButtonCell.cellFromButtonCell_direction_delay_(self.forwardButton.cell(), 1, 0.5))
         self.backwardButton.setCell_(SkipSeekButtonCell.cellFromButtonCell_direction_delay_(self.backwardButton.cell(), -1, 0.5))
+        self.muteButton.setEnabled_(YES)
+        self.volumeSlider.setEnabled_(YES)
         nc = NSNotificationCenter.defaultCenter()
         nc.addObserver_selector_name_object_(
             self, 
@@ -167,8 +178,6 @@ class VideoDisplayController (NibClassBuilder.AutoBaseClass):
     def enablePrimaryControls(self, enabled):
         self.playPauseButton.setEnabled_(enabled)
         self.fullscreenButton.setEnabled_(enabled)
-        self.muteButton.setEnabled_(enabled)
-        self.volumeSlider.setEnabled_(enabled and self.muteButton.state() is NSOnState)
 
     def enableSecondaryControls(self, enabled, allowFastSeeking=YES):
         self.backwardButton.setEnabled_(enabled)
@@ -350,7 +359,6 @@ class VideoAreaView (NibClassBuilder.AutoBaseClass):
 class VideoWindow (NibClassBuilder.AutoBaseClass):
     
     def initWithContentRect_styleMask_backing_defer_(self, rect, style, backing, defer):
-        platformutils.warnIfNotOnMainThread('VideoWindow.initWithContentRect_styleMask_backing_defer_')
         self = super(VideoWindow, self).initWithContentRect_styleMask_backing_defer_(
             rect,
             NSBorderlessWindowMask,
@@ -362,8 +370,7 @@ class VideoWindow (NibClassBuilder.AutoBaseClass):
         return self
 
     def setup(self, renderer, item):
-        if self.contentView() != renderer.view:
-            platformutils.callOnMainThreadAndWaitUntilDone(self.setContentView_, renderer.view)
+        self.installRendererView_(renderer.view)
         self.palette.setup(item, renderer)
         if self.isFullScreen:
             platformutils.callOnMainThreadAfterDelay(0.5, self.palette.reveal, self)
@@ -372,6 +379,12 @@ class VideoWindow (NibClassBuilder.AutoBaseClass):
         platformutils.warnIfNotOnMainThread('VideoWindow.teardown')
         self.setContentView_(nil)
 
+    @platformutils.onMainThreadWaitingUntilDone
+    def installRendererView_(self, view):
+        if self.contentView() is not nil:
+            self.contentView().removeFromSuperviewWithoutNeedingDisplay()
+        self.setContentView_(view)
+
     def canBecomeMainWindow(self):
         return self.isFullScreen
     
@@ -494,7 +507,6 @@ class FullScreenPalette (NibClassBuilder.AutoBaseClass):
     HOLD_TIME = 2
     
     def initWithContentRect_styleMask_backing_defer_(self, rect, style, backing, defer):
-        platformutils.warnIfNotOnMainThread('FullScreenPalette.initWithContentRect_styleMask_backing_defer_')
         self = super(FullScreenPalette, self).initWithContentRect_styleMask_backing_defer_(
             rect,
             NSBorderlessWindowMask,
