@@ -5,12 +5,16 @@ from frontend_implementation.HTMLDisplay import HTMLDisplay, getDTVAPIURL, getDT
 from frontend_implementation.Application import Application
 from frontend_implementation.UIBackendDelegate import UIBackendDelegate
 from frontend_implementation.MainFrame import MainFrame
-from frontend_implementation.VideoDisplay import VideoDisplay, PlaylistItem, PlaybackController
+from frontend_implementation.VideoDisplay import VideoDisplay, PlaybackController
+import frontend_implementation.UIStrings as UIStrings
+import frontend_implementation.startup as startup
 
 # these get set in components.pybridge.onStartup
 jsBridge = None
 vlcRenderer = None
 
+currentVideoPath = None # gets changed in MainFrame.onSelectedTabChange()
+
 def quit():
     jsBridge.closeWindow()
 
