@@ -171,6 +171,11 @@ function onLoad() {
     jsdump("onload done");
 }
 
+function setSearchEngine(engine) {
+    var searchIcon = document.getElementById("search-icon");
+    searchIcon.setAttribute("src",'images/search_icon_' + engine + '.png');
+}
+
 // SeekButton is used for both the rewind/previous and fast forward/next
 // buttons.  If clicked, they skip to the next/previous button.  If held downl
 // they do a fast forward/rewind.  direction should be 1 for forward, -1 for
@@ -353,9 +358,35 @@ function handleExit() {
 function onKeyDown(event) {
   if(event.altKey && event.keyCode == 13) { // Alt Enter
      onFullscreenActivate();
+     return false
   }
-  else if(event.keyCode == 8 || event.keyCode == 46) {  // Delete/Backspace
-     if(event.target.tagName.toLowerCase() == 'input') return;
+  if(event.ctrlKey) {
+    var charPressed = String.fromCharCode(event.keyCode).toLowerCase();
+    if(charPressed == 'o') {
+      openFile();
+      return false;
+    } else if(charPressed == 'p') {
+      if(event.shiftKey) pybridge.createNewPlaylistFolder();
+      else pybridge.createNewPlaylist();
+      return false;
+    } else if(charPressed == 'n') {
+      if(event.shiftKey) pybridge.createNewChannelFolder();
+      else pybridge.addChannel();
+      return false;
+    } else if(charPressed == 'd') {
+      pybridge.stop();
+      return false;
+    } else if(charPressed == 'f') {
+      onFullscreenActivate();
+      return false;
+    }
+  }
+  // Don't mess with keys in input boxes.
+  if(event.target.tagName) {
+    var lowerTagName = event.target.tagName.toLowerCase();
+    if(lowerTagName == 'input' || lowerTagName == 'textbox') return true;
+  }
+  if(event.keyCode == 8 || event.keyCode == 46) {  // Delete/Backspace
      pybridge.removeCurrentSelection();
   } else if(event.keyCode == 32) { // Space
     pybridge.playPause();
@@ -363,20 +394,18 @@ function onKeyDown(event) {
     pybridge.skip(1);
   } else if(event.keyCode == 37) { // Left Arrow
     pybridge.skip(-1);
-  } else if(event.ctrlKey) {
-    var charPressed = String.fromCharCode(event.keyCode).toLowerCase();
-    if(charPressed=='o') {
-      openFile();
-    } else if(charPressed == 'p') {
-      if(event.shiftKey) pybridge.createNewPlaylistFolder();
-      else pybridge.createNewPlaylist();
-    } else if(charPressed == 'n') {
-      if(event.shiftKey) pybridge.createNewChannelFolder();
-      else pybridge.addChannel();
-    } else if(charPressed == 'd') {
-      pybridge.stop();
-    } else if(charPressed == 'f') {
-      onFullscreenActivate();
-    }
+  } 
+  return false;
+}
+
+/* This is where the search on chrome events come to hang out */
+function onSearchKeyDown(event) {
+  if(event.keyCode == 13) {
+    /* hack to get engine from the UI */
+    var searchIcon = document.getElementById("search-icon");
+    var iconURL = searchIcon.getAttribute("src")
+    var name = iconURL.substring(19, iconURL.length - 4);
+
+    pybridge.performSearch(name, event.target.value);
   }
 }
