@@ -85,6 +85,7 @@ jsBridge.prototype = {
     this.hideVideoControlsTimer = Components.classes["@mozilla.org/timer;1"].
           createInstance(Components.interfaces.nsITimer);
     this.videoFilename = null;
+    this.searchEngineTitles = this.searchEngineNames = null;
 
     var self = this;
     self.lastMouseDownX = self.lastMouseDownY = 0;
@@ -136,6 +137,25 @@ jsBridge.prototype = {
     popup.showPopup(this.document.documentElement, this.lastMouseDownX,
         this.lastMouseDownY, "popup", null, null);
   },
+  showSearchMenu: function() {
+    if(!this.searchEngineNames || !this.searchEngineTitles) return;
+
+    var popup = this.document.getElementById('searchMenu');
+    while (popup.firstChild) {
+      popup.removeChild(popup.firstChild);
+    }
+    for (var i = 0; i < this.searchEngineNames.length; i++) {
+        var newItem = this.document.createElement('menuitem');
+        newItem.setAttribute("label", this.searchEngineTitles[i]);
+        newItem.setAttribute("image", "chrome://dtv/content/images/search_icon_" + this.searchEngineNames[i] + ".png");
+        newItem.setAttribute("class", "menuitem-iconic");
+        newItem.setAttribute("oncommand", 
+           "jsbridge.setSearchEngine('" + this.searchEngineNames[i] + "');");
+        popup.appendChild(newItem);
+    }
+    var textbox = this.document.getElementById('search-textbox');
+    popup.showPopup(textbox, -1, -1, "popup", "bottomleft", "topleft");
+  },
 
   showChoiceDialog: function(id, title, description, defaultLabel, otherLabel) {
     var params = { "id": id, "title": title, "description" : description, 
@@ -354,6 +374,16 @@ jsBridge.prototype = {
     elt.parentNode.removeChild(elt);
     next.parentNode.insertBefore(this.createNode(document, xml), next);
   },
+  xulChangeAttribute: function(area, id, name, value) {
+    var document = this.getDocument(area);
+    var elt = document.getElementById(id);
+    elt.setAttribute(name, value);
+  },
+  xulRemoveAttribute: function(area, id, name) {
+    var document = this.getDocument(area);
+    var elt = document.getElementById(id);
+    elt.removeAttribute(name);
+  },
   xulHideElement: function(area, id) {
     var document = this.getDocument(area);
     var elt = document.getElementById(id);
@@ -439,6 +469,16 @@ jsBridge.prototype = {
     var progressSlider = this.document.getElementById("progress-slider");
     progressSlider.left = newSliderPos;
   },
+
+  setSearchEngineInfo: function(names, titles) {
+    this.searchEngineNames = names;
+    this.searchEngineTitles = titles;
+  },
+
+  setSearchEngine: function(engine) {
+    var searchIcon = this.document.getElementById("search-icon");
+    searchIcon.setAttribute("src",'images/search_icon_' + engine + '.png');
+  },
 };
 
 var Module = {
