@@ -27,6 +27,8 @@ try:
     from frontend_implementation.UIBackendDelegate import UIBackendDelegate
     from eventloop import asUrgent
     from platformutils import getLongPathName
+    import searchengines
+    import views
 except:
     errorOnImport = True
     # get a fallback error message in case we can't import util either
@@ -103,7 +105,7 @@ def getArgumentList(commandLine):
         args = args[1:]
     return [getLongPathName(path) for path in args]
 
-# Copied from resource.py; if you change this function here, change it
+# Copied from resources.py; if you change this function here, change it
 # there too.
 def appRoot():
     klass = components.classes["@mozilla.org/file/directory_service;1"]
@@ -146,6 +148,7 @@ class PyBridge:
 
         initializeProxyObjects(window)
         app.main()
+        self.initializeSearchEngines()
 
     def onShutdown(self):
         frontend.vlcRenderer.stop()
@@ -207,6 +210,13 @@ class PyBridge:
         return config.get(prefs.UPSTREAM_LIMIT_IN_KBS)
     def setLimitUpstreamAmount(self, value):
         return config.set(prefs.UPSTREAM_LIMIT_IN_KBS, value)
+    def getMaxManual(self):
+        return config.get(prefs.MAX_MANUAL_DOWNLOADS)
+    def setMaxManual(self, value):
+        return config.set(prefs.MAX_MANUAL_DOWNLOADS, value)
+    def updatePrefs(self):
+        import autodler
+        autodler.updatePrefs()
     def getPreserveDiskSpace(self):
         return config.get(prefs.PRESERVE_DISK_SPACE)
     def setPreserveDiskSpace(self, value):
@@ -323,6 +333,10 @@ class PyBridge:
     def skipPrevious(self):
         app.controller.playbackController.skip(-1, allowMovieReset=False)
 
+    @asUrgent
+    def onMovieFinished(self):
+        app.controller.playbackController.onMovieFinished()
+
     @asUrgent
     def loadURLInBrowser(self, browserId, url):
         try:
@@ -332,6 +346,23 @@ class PyBridge:
         else:
             display.onURLLoad(url)
 
+    @asUrgent
+    def performSearch(self, engine, query):
+        app.controller.performSearch(engine, query)
+
+    # Returns a list of search engine titles and names
+    # Should we just keep a map of engines to names?
+    def getSearchEngineNames(self):
+        out = []
+        for engine in views.searchEngines:
+            out.append(engine.name)
+        return out
+    def getSearchEngineTitles(self):
+        out = []
+        for engine in views.searchEngines:
+            out.append(engine.title)
+        return out
+
     def showCursor(self, display):
         # ShowCursor has an amazing API.  From Microsoft:
         #
@@ -446,3 +477,15 @@ class PyBridge:
 
     def createProxyObjects(self):
         createProxyObjects()
+
+    @asUrgent
+    def initializeSearchEngines(self):
+        # Send the search engine info to jsbridge.  This is a little tricky
+        # because we need to access views.searchEngines from the main thread.
+        names = []
+        titles = []
+        for engine in views.searchEngines:
+            names.append(engine.name)
+            titles.append(engine.title)
+        frontend.jsBridge.setSearchEngineInfo(names, titles)
+        frontend.jsBridge.setSearchEngine(searchengines.getLastEngine())
