@@ -20,7 +20,7 @@ import tabs
 import folder
 import autodler
 import databaseupgrade
-import resource
+import resources
 import selection
 import template
 import singleclick
@@ -48,7 +48,7 @@ import datetime
 import threading
 import platform
 import dialogs
-from iconcache import iconCacheUpdater
+import iconcache
 
 # Something needs to import this outside of Pyrex. Might as well be app
 import templatehelper
@@ -84,6 +84,7 @@ class PlaybackControllerBase:
     def __init__(self):
         self.currentPlaylist = None
         self.justPlayOne = False
+        self.currentItem = None
 
     def configure(self, view, firstItemId=None, justPlayOne=False):
         self.currentPlaylist = Playlist(view, firstItemId)
@@ -127,16 +128,25 @@ class PlaybackControllerBase:
         else:
             self.enterPlayback()
 
+    def removeItem(self, item):
+        if item.idExists():
+            item.executeExpire()
+
     def playItem(self, anItem):
         try:
+            if self.currentItem:
+                self.currentItem.onViewedCancel()
+            self.currentItem = None
             while not os.path.exists(anItem.getVideoFilename()):
                 print "DTV: movie file '%s' is missing, skipping to next" % \
                         anItem.getVideoFilename()
+                eventloop.addIdle(self.removeItem, "Remove deleted item", args=(anItem.item,))
                 anItem = self.currentPlaylist.getNext()
                 if anItem is None:
                     self.stop()
                     return
 
+            self.currentItem = anItem
             if anItem is not None:
                 videoDisplay = controller.videoDisplay
                 videoRenderer = videoDisplay.getRendererForItem(anItem)
@@ -163,7 +173,7 @@ class PlaybackControllerBase:
     def playItemExternally(self, itemID):
         anItem = mapToPlaylistItem(db.getObjectByID(int(itemID)))
         controller.videoInfoItem = anItem
-        newDisplay = TemplateDisplay('external-playback-continue')
+        newDisplay = TemplateDisplay('external-playback-continue','default')
         frame = controller.frame
         frame.selectDisplay(newDisplay, frame.mainDisplay)
         return anItem
@@ -171,11 +181,14 @@ class PlaybackControllerBase:
     def scheduleExternalPlayback(self, anItem):
         controller.videoDisplay.stopOnDeselect = False
         controller.videoInfoItem = anItem
-        newDisplay = TemplateDisplay('external-playback')
+        newDisplay = TemplateDisplay('external-playback','default')
         frame = controller.frame
         frame.selectDisplay(newDisplay, frame.mainDisplay)
 
-    def stop(self, switchDisplay=True):
+    def stop(self, switchDisplay=True, markAsViewed=False):
+        if self.currentItem:
+            self.currentItem.onViewedCancel()
+        self.currentItem = None
         frame = controller.frame
         videoDisplay = controller.videoDisplay
         if frame.getDisplay(frame.mainDisplay) == videoDisplay:
@@ -204,6 +217,7 @@ class PlaybackControllerBase:
                 self.playItem(nextItem)
 
     def onMovieFinished(self):
+        self.currentItem = None
         return self.skip(1, False)
 
 
@@ -297,7 +311,7 @@ class VideoDisplayBase (Display):
     def selectItem(self, anItem, renderer):
         self.stopOnDeselect = True
         controller.videoInfoItem = anItem
-        template = TemplateDisplay('video-info')
+        template = TemplateDisplay('video-info','default')
         area = controller.frame.videoInfoDisplay
         controller.frame.selectDisplay(template, area)
         
@@ -608,7 +622,7 @@ class Controller (frontend.Application):
             eventloop.addTimeout (30, autoupdate.checkForUpdates, "Check for updates")
             feed.expireItems()
 
-            self.tabDisplay = TemplateDisplay('tablist',
+            self.tabDisplay = TemplateDisplay('tablist','default',
                     playlistTabOrder=playlistTabOrder,
                     channelTabOrder=channelTabOrder)
             self.frame.selectDisplay(self.tabDisplay, self.frame.channelsDisplay)
@@ -636,6 +650,10 @@ class Controller (frontend.Application):
 
             util.print_mem_usage("Post single-click memory check")
 
+            start = clock()
+            iconcache.clearOrphans()
+            print "Icon clear: %.3f" % (clock() - start,)
+
             print "DTV: Starting event loop thread"
             eventloop.startup()            
 
@@ -658,15 +676,23 @@ You must download the latest version of Democracy and run that.""")
 
     def setupGlobalFeed(self, url, *args, **kwargs):
         feedView = views.feeds.filterWithIndex(indexes.feedsByURL, url)
-        hasFeed = feedView.len() > 0
-        feedView.unlink()
-        if not hasFeed:
-            print "DTV: Spawning global feed %s" % url
-            d = feed.Feed(url, *args, **kwargs)
+        try:
+            if feedView.len() == 0:
+                print "DTV: Spawning global feed %s" % url
+                d = feed.Feed(url, *args, **kwargs)
+            elif feedView.len() > 1:
+                allFeeds = [f for f in feedView]
+                for extra in allFeeds[1:]:
+                    extra.remove()
+                util.failed("Too many db objects for %s" % url)
+        finally:
+            feedView.unlink()
 
     def getGlobalFeed(self, url):
         feedView = views.feeds.filterWithIndex(indexes.feedsByURL, url)
-        return feedView[0]
+        rv = feedView[0]
+        feedView.unlink()
+        return rv
 
     def removeGlobalFeed(self, url):
         feedView = views.feeds.filterWithIndex(indexes.feedsByURL, url)
@@ -931,7 +957,7 @@ downloaded?""")
                 self.removeGlobalFeed('dtv:search')
 
                 print "DTV: Shutting down icon cache updates"
-                iconCacheUpdater.shutdown()
+                iconcache.iconCacheUpdater.shutdown()
 
                 print "DTV: Removing static tabs..."
                 views.allTabs.unlink() 
@@ -1014,6 +1040,16 @@ downloaded?""")
         count = views.unwatchedItems.len()
         delegate.updateAvailableItemsCountFeedback(count)
 
+    ### Chrome search:
+    ### Switch to the search tab and perform a search using the specified engine.
+
+    def performSearch(self, engine, query):        
+        handler = TemplateActionHandler(None, None)
+        handler.updateLastSearchEngine(engine)
+        handler.updateLastSearchQuery(query)
+        handler.performSearch(engine, query)
+        self.selection.selectTabByTemplateBase('searchtab')
+
     ### ----
 
     def setUpstreamLimit(self, setLimit):
@@ -1111,13 +1147,15 @@ downloaded?""")
 
 class TemplateDisplay(frontend.HTMLDisplay):
 
-    def __init__(self, templateName, frameHint=None, areaHint=None, 
+    def __init__(self, templateName, templateState, frameHint=None, areaHint=None, 
             baseURL=None, *args, **kargs):
-        "'templateName' is the name of the inital template file. 'data' is keys for the template."
+        "'templateName' is the name of the inital template file. 'data' is keys for the template. 'templateState' is a string with the state of the template"
 
         #print "Processing %s" % templateName
         self.templateName = templateName
-        (tch, self.templateHandle) = template.fillTemplate(templateName, self,
+        self.templateState = templateState
+        (tch, self.templateHandle) = template.fillTemplate(templateName,
+                templateState, self,
                 self.getDTVPlatformName(), self.getEventCookie(),
                 self.getBodyTagExtra(), *args, **kargs)
         self.args = args
@@ -1150,6 +1188,15 @@ class TemplateDisplay(frontend.HTMLDisplay):
     def __str__(self):
         return "Template <%s> args=%s kargs=%s" % (self.templateName, self.args, self.kargs)
 
+    def reInit(self, *args, **kargs):
+        self.args = args
+        self.kargs = kargs
+        try:
+            self.templateHandle.templateVars['reInit'](*args, **kargs)
+        except:
+            pass
+        self.templateHandle.forceUpdate()
+        
     def runActionURLs(self, triggers):
         newPage = False
         for url in triggers:
@@ -1208,6 +1255,24 @@ class TemplateDisplay(frontend.HTMLDisplay):
                 path = url[len("file://"):]
                 return os.path.exists(path)
 
+            if url.startswith('feed://'):
+                url = "http://" + url[len("feed://"):]
+                f = feed.getFeedByURL(url)
+                if f is None:
+                    f = feed.Feed(url)
+                f.blink()
+                return True
+
+            # check for subscribe.getdemocracy.com links
+            subscribeLinks = subscription.findSubscribeLinks(url)
+            if subscribeLinks:
+                for url in subscribeLinks:
+                    f = feed.getFeedByURL(url)
+                    if f is None:
+                        f = feed.Feed(url)
+                    f.blink()
+                return True
+
             # If we get here, this isn't a DTV URL. We should open it
             # in an external browser.
             if (url.startswith('http://') or url.startswith('https://') or
@@ -1232,19 +1297,32 @@ class TemplateDisplay(frontend.HTMLDisplay):
         for guide in views.guides:
             if url.startswith(guide.getRedirectedURL()):
                 return
+
+        # check for subscribe.getdemocracy.com links
+        subscribeLinks = subscription.findSubscribeLinks(url)
+        if subscribeLinks:
+            for url in subscribeLinks:
+                f = feed.getFeedByURL(url)
+                if f is None:
+                    f = feed.Feed(url)
+                f.blink()
+            return
         delegate.openExternalURL(url)
 
     @eventloop.asUrgent
     def dispatchAction(self, action, **kwargs):
+        called = False
         start = clock()
         for handler in self.actionHandlers:
             if hasattr(handler, action):
                 getattr(handler, action)(**kwargs)
-                return
+                called = True
+                break
         end = clock()
         if end - start > 0.5:
             print "WARNING: dispatch action %s too slow (%.3f secs)" % (action, end - start)
-        print "Ignored bad action URL: action=%s" % action
+        if not called:
+            print "Ignored bad action URL: action=%s" % action
 
     @eventloop.asUrgent
     def onDeselected(self, frame):
@@ -1427,7 +1505,7 @@ class ModelActionHandler:
     def videoBombExternally(self, item):
         obj = db.getObjectByID(int(item))
         paramList = {}
-        paramList["title"] = obj.getTitle()
+        paramList["title"] = obj.getTitle().encode('utf-8')
         paramList["info_url"] = obj.getLink()
         paramList["hookup_url"] = obj.getPaymentLink()
         try:
@@ -1447,6 +1525,7 @@ class ModelActionHandler:
        
         # This should be first, since it's most important.
         url = obj.getURL()
+        url.encode('utf-8', 'replace')
         if (not url.startswith('file:')):
             paramString = "?url=%s" % xhtmltools.urlencode(url)
             glue = '&'
@@ -1491,7 +1570,10 @@ class GUIActionHandler:
             if dialog.choice == dialogs.BUTTON_CREATE_CHANNEL:
                 self.addFeed(dialog.getURL())
         dialog = dialogs.SearchChannelDialog(term, style, location)
-        dialog.run(doAdd)
+        if location == None:
+            dialog.run(doAdd)
+        else:
+            self.addFeed(dialog.getURL())
 
     def addChannelSearchFeed(self, term, id):
         self.addSearchFeed(term, dialogs.SearchChannelDialog.CHANNEL, int(id))
@@ -1592,7 +1674,7 @@ class TemplateActionHandler:
         self.templateHandle = templateHandle
         self.currentName = None
 
-    def switchTemplate(self, name, baseURL=None, *args, **kargs):
+    def switchTemplate(self, name, state='default', baseURL=None, *args, **kargs):
         self.templateHandle.unlinkTemplate()
         # Switch to new template. It get the same variable
         # dictionary as we have.
@@ -1600,20 +1682,12 @@ class TemplateActionHandler:
         # that these links always affect the right-hand 'content'
         # area, even if they are loaded from the left-hand 'tab'
         # area. Actually this whole invocation is pretty hacky.
-        template = TemplateDisplay(name, frameHint=controller.frame,
+        template = TemplateDisplay(name, state, frameHint=controller.frame,
                 areaHint=controller.frame.mainDisplay, baseURL=baseURL,
                 *args, **kargs)
         controller.frame.selectDisplay(template, controller.frame.mainDisplay)
         self.currentName = name
 
-    def doneWithIntro(self, id):
-        try:
-            guide = views.guides.getObjectByID(int(id)).setSawIntro()
-        except database.ObjectNotFoundError: 
-            # guide was deleted before we got this action URL
-            return
-        self.goToGuide(id)
-
     def goToGuide(self, id):
         # Only switch to the guide if the template display is already
         # selected This prevents doubling clicking on a movie from
@@ -1724,7 +1798,6 @@ class TemplateActionHandler:
             searchFeed.lastQuery = query
         
     def performSearch(self, engine, query):
-        print "Performing search"
         searchFeed, searchDownloadsFeed = self.__getSearchFeeds()
         if searchFeed is not None and searchDownloadsFeed is not None:
             searchFeed.preserveDownloads(searchDownloadsFeed)
@@ -1749,7 +1822,6 @@ class TemplateActionHandler:
         try:
             obj = db.getObjectByID(int(id))
         except:
-            print "WARNING: error parsing context menu request (%s)" % data
             traceback.print_exc()
         else:
             view = self.templateHandle.getTemplateVariable(viewName)
@@ -1829,13 +1901,14 @@ class Playlist:
 
     def itemMarkedAsViewed(self, anItem):
         if anItem is not None:
-            eventloop.addIdle(lambda:anItem.onViewed(), "Mark item viewed")
+            eventloop.addIdle(anItem.onViewed, "Mark item viewed")
         return anItem
 
 class PlaylistItemFromItem:
 
     def __init__(self, anItem):
         self.item = anItem
+        self.dcOnViewed = None
 
     def getTitle(self):
         return self.item.getTitle()
@@ -1847,9 +1920,20 @@ class PlaylistItemFromItem:
         # NEEDS
         return 42.42
 
-    def onViewed(self):
+    def onViewedExecute(self):
         if self.item.idExists():
             self.item.markItemSeen()
+        self.dcOnViewed = None
+
+    def onViewed(self):
+        if self.dcOnViewed or self.item.getSeen():
+            return
+        self.dcOnViewed = eventloop.addTimeout(5, self.onViewedExecute, "Mark item viewed")
+
+    def onViewedCancel(self):
+        if self.dcOnViewed:
+            self.dcOnViewed.cancel()
+            self.dcOnViewed = None
 
     # Return the ID that is used by a template to indicate this item 
     def getID(self):
@@ -1864,12 +1948,8 @@ def mappableToPlaylistItem(obj):
 def mapToPlaylistItem(obj):
     return PlaylistItemFromItem(obj)
 
-class TooManySingletonsError(Exception):
-    pass
-
 def _defaultFeeds():
     defaultFeedURLs = [
-        'http://del.icio.us/rss/representordie/system:media:video', 
         'http://www.videobomb.com/rss/posts/front',
         'http://www.mediarights.org/bm/rss.php?i=1',
         'http://www.telemusicvision.com/videos/rss.php?i=1',
@@ -1881,6 +1961,12 @@ def _defaultFeeds():
     ]
     if len(platform.mac_ver()[0]) > 0:
         defaultFeedURLs.append('http://libsyn.com/podcasts/donmc/_static/scoipod.xml')
+
+    # HACK: The "Represent Or Die" default channel uses its URL as a
+    # title, which sucks (per #4710). Rename it.
+    rod = feed.Feed('http://del.icio.us/rss/representordie/system:media:video', initiallyAutoDownloadable=False)
+    rod.setTitle ('ROD')
+
     for url in defaultFeedURLs:
         feed.Feed(url, initiallyAutoDownloadable=False)
     playlist.SavedPlaylist(_("Example Playlist"))
@@ -1896,7 +1982,7 @@ def _getInitialChannelGuide():
     if default_guide is None:
         print "DTV: Spawning Channel Guide..."
         default_guide = guide.ChannelGuide()
-        initialFeeds = resource.path("initial-feeds.democracy")
+        initialFeeds = resources.path("initial-feeds.democracy")
         if os.path.exists(initialFeeds):
             urls = subscription.parseFile(initialFeeds)
             if urls is not None:
