@@ -4,9 +4,10 @@ import traceback
 
 import util
 import prefs
-import resource
+import resources
 import eventloop
 import platformcfg
+import urllib
 
 __appConfig = None
 __data = None
@@ -35,7 +36,7 @@ def load():
             # call config.get() or config.set() from platformcfg.load()
             # unless you know exactly what you are doing, and maybe not
             # even then.
-            __appConfig = util.readSimpleConfigFile(resource.path('app.config'))
+            __appConfig = util.readSimpleConfigFile(resources.path('app.config'))
 
             # Load the preferences
             __data = platformcfg.load()
@@ -78,6 +79,9 @@ def get(descriptor):
     finally:
         __lock.release()
 
+def getList(descriptor):
+    return [urllib.unquote(i) for i in get(descriptor).split(",") if i]
+
 def getAppConfig():
     __lock.acquire()
     try:
@@ -100,6 +104,9 @@ def set(descriptor, value):
     finally:
         __lock.release()
 
+def setList(descriptor, value):
+    set(descriptor, [quote(i) for i in value].join (','))
+
 def __checkValidity():
     if __appConfig == None:
         load()
