@@ -295,6 +295,149 @@ def upgrade24(objectList):
                 o.savedData['status']['metainfo'] = None
                 o.savedData['status']['infohash'] = None
 
+def upgrade25(objectList):
+    """Remove container items from playlists."""
+
+    from datetime import datetime
+
+    changed = set()
+    startfroms = {}
+    for o in objectList:
+        if o.classString == 'feed':
+            startfroms[o.savedData['id']] = o.savedData['actualFeed'].savedData['startfrom']
+    for o in objectList:
+        if o.classString == 'item':
+            pubDate = o.savedData['releaseDateObj']
+            feed_id = o.savedData['feed_id']
+            if feed_id is not None and startfroms.has_key(feed_id):
+                o.savedData['eligibleForAutoDownload'] = pubDate != datetime.max and pubDate >= startfroms[feed_id]
+            else:
+                o.savedData['eligibleForAutoDownload'] = False
+            changed.add(o)
+        if o.classString == 'file-item':
+            o.savedData['eligibleForAutoDownload'] = True
+            changed.add(o)
+    return changed
+
+def upgrade26(objectList):
+    changed = set()
+    for o in objectList:
+        if o.classString == 'feed':
+            feedImpl = o.savedData['actualFeed']
+            for field in ('autoDownloadable', 'getEverything', 'maxNew', 'fallBehind', 'expire', 'expireTime'):
+                o.savedData[field] = feedImpl.savedData[field]
+            changed.add(o)
+    return changed
+
+def upgrade27(objectList):
+    """We dropped the sawIntro field from ChannelGuide.  No need to change
+    anything for this."""
+    return set()
+
+def upgrade28(objectList):
+    import feed
+    objectList.sort(key=lambda o:o.savedData['id'])
+    changed = set()
+    items = set()
+    removed = set()
+
+    def isVideoEnclosure(enclosure):
+        """
+        Pass an enclosure dictionary to this method and it will return a boolean
+        saying if the enclosure is a video or not.
+        """
+        return (_hasVideoType(enclosure) or
+                _hasVideoExtension(enclosure, 'url') or
+                _hasVideoExtension(enclosure, 'href'))
+    
+    def getFirstVideoEnclosure(entry):
+        """Find the first video enclosure in a feedparser entry.  Returns the
+        enclosure, or None if no video enclosure is found.
+        """
+    
+        try:
+            enclosures = entry.enclosures
+        except (KeyError, AttributeError):
+            return None
+        for enclosure in enclosures:
+            if isVideoEnclosure(enclosure):
+                return enclosure
+        return None
+
+    def _hasVideoType(enclosure):
+        return ('type' in enclosure and
+                (enclosure['type'].startswith('video/') or
+                 enclosure['type'].startswith('audio/') or
+                 enclosure['type'] == "application/ogg" or
+                 enclosure['type'] == "application/x-annodex" or
+                 enclosure['type'] == "application/x-bittorrent" or
+                 enclosure['type'] == "application/x-shockwave-flash"))
+    
+    def _hasVideoExtension(enclosure, key):
+        return (key in enclosure and isAllowedFilename(enclosure[key]))
+    
+    def isAllowedFilename(filename):
+        return (isVideoFilename(filename) or
+                isAudioFilename(filename) or
+                isTorrentFilename(filename))
+    
+    def isVideoFilename(filename):
+        return ((len(filename) > 4 and
+                 filename[-4:].lower() in ['.mov', '.wmv', '.mp4', '.m4v',
+                                           '.ogg', '.anx', '.mpg', '.avi', 
+                                           '.flv']) or
+                (len(filename) > 5 and
+                 filename[-5:].lower() == '.mpeg'))
+    
+    def isAudioFilename(filename):
+        return len(filename) > 4 and filename[-4:].lower() in ['.mp3', '.m4a']
+    
+    def isTorrentFilename(filename):
+        return filename.endswith('.torrent')
+    
+    for i in xrange (len(objectList) - 1, -1, -1):
+        o = objectList [i]
+        if o.classString == 'item':
+            entry = o.savedData['entry']
+            videoEnc = getFirstVideoEnclosure(entry)
+            if videoEnc is not None:
+                entryURL = videoEnc.get('url')
+            else:
+                entryURL = None
+            title = entry.get("title")
+            feed_id = o.savedData['feed_id']
+            if title is not None or entryURL is not None:
+                if (feed_id, entryURL, title) in items:
+                    removed.add (o.savedData['id'])
+                    changed.add(o)
+                    del objectList[i]
+                else:
+                    items.add((feed_id, entryURL, title))
+
+    for i in xrange (len(objectList) - 1, -1, -1):
+        o = objectList [i]
+        if o.classString == 'file-item':
+            if o.savedData['parent_id'] in removed:
+                changed.add(o)
+                del objectList[i]
+    return changed
+
+def upgrade29(objectList):
+    changed = set()
+    for o in objectList:
+        if o.classString == 'guide':
+            o.savedData['default'] = (o.savedData['url'] is None)
+            changed.add(o)
+    return changed
+
+def upgrade30(objectList):
+    changed = set()
+    for o in objectList:
+        if o.classString == 'guide':
+            if o.savedData['default']:
+                o.savedData['url'] = None
+                changed.add(o)
+    return changed
 
 #def upgradeX (objectList):
 #    """ upgrade an object list to X.  return set of changed savables. """
