@@ -28,7 +28,7 @@ import eventloop
 import folder
 import menu
 import prefs
-import resource
+import resources
 import util
 import views
 import indexes
@@ -38,10 +38,10 @@ from clock import clock
 whitespacePattern = re.compile(r"^[ \t\r\n]*$")
 
 def defaultFeedIconURL():
-    return resource.url("images/feedicon.png")
+    return resources.url("images/feedicon.png")
 
 def defaultFeedIconURLTablist():
-    return resource.url("images/feedicon-tablist.png")
+    return resources.url("images/feedicon-tablist.png")
 
 # Notes on character set encoding of feeds:
 #
@@ -76,7 +76,7 @@ def addFeedFromFile(file):
     d = feedparser.parse(file)
     if d.feed.has_key('links'):
         for link in d.feed['links']:
-            if link['rel'] == 'start':
+            if link['rel'] == 'start' or link['rel'] == 'self':
                 Feed(link['href'])
                 return
     if d.feed.has_key('link'):
@@ -162,8 +162,6 @@ config.addChangeCallback(configDidChange)
 # Actual implementation of a basic feed.
 class FeedImpl:
     def __init__(self, url, ufeed, title = None, visible = True):
-        self.available = 0
-        self.unwatched = 0
         self.url = url
         self.ufeed = ufeed
         self.calc_item_list()
@@ -172,22 +170,24 @@ class FeedImpl:
         else:
             self.title = title
         self.created = datetime.now()
-        self.autoDownloadable = ufeed.initiallyAutoDownloadable
-        self.startfrom = datetime.max
-        self.getEverything = False
-        self.maxNew = -1
-        self.fallBehind = -1
-        self.expire = "system"
         self.visible = visible
         self.updating = False
         self.lastViewed = datetime.min
         self.thumbURL = defaultFeedIconURL()
         self.initialUpdate = True
         self.updateFreq = config.get(prefs.CHECK_CHANNELS_EVERY_X_MN)*60
-        self.expireTime = None
 
     def calc_item_list(self):
         self.items = views.toplevelItems.filterWithIndex(indexes.itemsByFeed, self.ufeed.id)
+        self.availableItems = self.items.filter(lambda x: x.getState() == 'new')
+        self.unwatchedItems = self.items.filter(lambda x: x.getState() == 'newly-downloaded')
+        self.availableItems.addAddCallback(lambda x,y:DDBObject.signalChange(self.ufeed))
+        self.availableItems.addRemoveCallback(lambda x,y:DDBObject.signalChange(self.ufeed))
+        self.unwatchedItems.addAddCallback(lambda x,y:DDBObject.signalChange(self.ufeed))
+        self.unwatchedItems.addRemoveCallback(lambda x,y:DDBObject.signalChange(self.ufeed))
+        
+    def signalChange(self):
+        self.ufeed.signalChange()
 
     def getBaseHref(self):
         """Get a URL to use in the <base> tag for this channel.  This is used
@@ -245,37 +245,13 @@ class FeedImpl:
         except:
             print "%s has no ufeed" % self
 
-    # Updates the state of unwatched and available items to meet
-    # Returns true iff signalChange() is called
-    def updateUandA(self, signal = True):
-        self.ufeed.confirmDBThread()
-        newU = 0
-        newA = 0
-
-        for item in self.items:
-            # FIXME: I think it's bad style to use the CSS class here.  The
-            # problem is that what we want isn't getState() or
-            # getChannelCategory(), since we don't want to count new items
-            # that are also going to be auto-downloaded.  Maybe make a
-            # method called getDisplayState or something?.
-            (u, a) = item.getUandA()
-            newA += a
-            newU += u
-        if newU != self.unwatched or newA != self.available:
-            self.unwatched = newU
-            self.available = newA
-            if signal:
-                self.ufeed.signalChange(needsSave=False)
-            if self.ufeed.folder_id:
-                self.ufeed.getFolder().signalChange(needsSave=False)
-            
     # Returns string with number of unwatched videos in feed
     def numUnwatched(self):
-        return self.unwatched
+        return len(self.unwatchedItems)
 
     # Returns string with number of available videos in feed
     def numAvailable(self):
-        return self.available
+        return len(self.availableItems)
 
     # Returns true iff both unwatched and available numbers should be shown
     def showBothUAndA(self):
@@ -283,11 +259,11 @@ class FeedImpl:
 
     # Returns true iff unwatched should be shown 
     def showU(self):
-        return self.unwatched > 0
+        return len(self.unwatchedItems) > 0
 
     # Returns true iff available should be shown
     def showA(self):
-        return self.available > 0 and not self.isAutoDownloadable()
+        return len(self.availableItems) > 0 and not self.isAutoDownloadable()
 
     ##
     # Sets the last time the feed was viewed to now
@@ -296,7 +272,6 @@ class FeedImpl:
         for item in self.items:
             if item.getState() == "new":
                 item.signalChange(needsSave=False)
-        self.updateUandA(False)
 
         self.ufeed.signalChange()
 
@@ -372,66 +347,6 @@ class FeedImpl:
         for item in self.items:
             item.signalChange(needsSave=False)
 
-    ##
-    # Switch the auto-downloadable state
-    def setAutoDownloadable(self, automatic):
-        self.ufeed.confirmDBThread()
-        auto = set()
-        for item in self.items:
-            if item.isEligibleForAutoDownload():
-                auto.add(item)
-        self.autoDownloadable = (automatic == "1")
-        if self.autoDownloadable:
-            self.startfrom = datetime.now()
-        else:
-            self.startfrom = datetime.max
-        for item in self.items:
-            if item.isEligibleForAutoDownload() or item in auto:
-                item.signalChange(needsSave=False)
-        self.ufeed.signalChange()
-
-    ##
-    # Sets the 'getEverything' attribute, True or False
-    def setGetEverything(self, everything):
-        self.ufeed.confirmDBThread()
-        wereAuto = set()
-        for item in self.items:
-            if item.isEligibleForAutoDownload():
-                wereAuto.add(item)
-        self.getEverything = everything
-        self.ufeed.signalChange()
-        self.signalAutoItems(wereAuto)
-
-    ##
-    # Sets the expiration attributes. Valid types are 'system', 'feed' and 'never'
-    # Expiration time is in hour(s).
-    def setExpiration(self, type, time):
-        self.ufeed.confirmDBThread()
-        self.expire = type
-        self.expireTime = timedelta(hours=time)
-
-        if self.expire == "never":
-            for item in self.items:
-                if item.isDownloaded():
-                    item.save()
-
-        self.ufeed.signalChange()
-        for item in self.items:
-            item.signalChange(needsSave=False)
-
-    ##
-    # Sets the maxNew attributes. -1 means unlimited.
-    def setMaxNew(self, maxNew):
-        self.ufeed.confirmDBThread()
-        oldMaxNew = self.maxNew
-        self.maxNew = maxNew
-        self.ufeed.signalChange()
-#        for item in self.items:
-#            item.signalChange(needsSave=False)
-        if self.maxNew >= oldMaxNew or self.maxNew < 0:
-            import autodler
-            autodler.autoDownloader.startDownloads()
-
     ##
     # Return the 'system' expiration delay, in days (can be < 1.0)
     def getDefaultExpiration(self):
@@ -458,25 +373,25 @@ class FeedImpl:
     # Returns "feed," "system," or "never"
     def getExpirationType(self):
         self.ufeed.confirmDBThread()
-        return self.expire
+        return self.ufeed.expire
 
     ##
     # Returns"unlimited" or the maximum number of items this feed can fall behind
     def getMaxFallBehind(self):
         self.ufeed.confirmDBThread()
-        if self.fallBehind < 0:
+        if self.ufeed.fallBehind < 0:
             return "unlimited"
         else:
-            return self.fallBehind
+            return self.ufeed.fallBehind
 
     ##
     # Returns "unlimited" or the maximum number of items this feed wants
     def getMaxNew(self):
         self.ufeed.confirmDBThread()
-        if self.maxNew < 0:
+        if self.ufeed.maxNew < 0:
             return "unlimited"
         else:
-            return self.maxNew
+            return self.ufeed.maxNew
 
     ##
     # Returns the total absolute expiration time in hours.
@@ -485,12 +400,12 @@ class FeedImpl:
         delta = None
         self.ufeed.confirmDBThread()
         expireAfterSetting = config.get(prefs.EXPIRE_AFTER_X_DAYS)
-        if (self.expireTime is None or self.expire == 'never' or 
-            (self.expire == 'system' and expireAfterSetting <= 0)):
+        if (self.ufeed.expireTime is None or self.ufeed.expire == 'never' or 
+            (self.ufeed.expire == 'system' and expireAfterSetting <= 0)):
             return 0
         else:
-            return (self.expireTime.days * 24 + 
-                    self.expireTime.seconds / 3600)
+            return (self.ufeed.expireTime.days * 24 + 
+                    self.ufeed.expireTime.seconds / 3600)
 
     ##
     # Returns the number of days until a video expires
@@ -498,7 +413,7 @@ class FeedImpl:
         ret = 0
         self.ufeed.confirmDBThread()
         try:
-            return self.expireTime.days
+            return self.ufeed.expireTime.days
         except:
             return timedelta(days=config.get(prefs.EXPIRE_AFTER_X_DAYS)).days
 
@@ -508,20 +423,20 @@ class FeedImpl:
         ret = 0
         self.ufeed.confirmDBThread()
         try:
-            return int(self.expireTime.seconds/3600)
+            return int(self.ufeed.expireTime.seconds/3600)
         except:
             return int(timedelta(days=config.get(prefs.EXPIRE_AFTER_X_DAYS)).seconds/3600)
 
     def getExpires (self):
         expireAfterSetting = config.get(prefs.EXPIRE_AFTER_X_DAYS)
-        return (self.expireTime is None or self.expire == 'never' or 
-                (self.expire == 'system' and expireAfterSetting <= 0))
+        return (self.ufeed.expireTime is None or self.ufeed.expire == 'never' or 
+                (self.ufeed.expire == 'system' and expireAfterSetting <= 0))
 
     ##
     # Returns true iff item is autodownloadable
     def isAutoDownloadable(self):
         self.ufeed.confirmDBThread()
-        return self.autoDownloadable
+        return self.ufeed.autoDownloadable
 
     def autoDownloadStatus(self):
         status = self.isAutoDownloadable()
@@ -600,8 +515,6 @@ class FeedImpl:
 
     def onRestore(self):
         self.updating = False
-        self.available = 0
-        self.unwatched = 0
         self.calc_item_list()
 
     def onRemove(self):
@@ -612,25 +525,6 @@ class FeedImpl:
     def __str__(self):
         return "FeedImpl - %s" % self.getTitle()
 
-
-updaterDC = None
-updaterSet = set()
-def updateUandAs():
-    global updaterSet
-    global updaterDC
-    for feedimpl in updaterSet:
-        if feedimpl.ufeed.idExists():
-            feedimpl.updateUandA()
-    updaterSet = set()
-    updaterDC = None
-
-def updateUandA(feed):
-    global updaterSet
-    global updaterDC
-    updaterSet.add (feed.actualFeed)
-    if updaterDC is None:
-        updaterDC = eventloop.addIdle(updateUandAs, "Update unwatched counts")
-
 ##
 # This class is a magic class that can become any type of feed it wants
 #
@@ -638,9 +532,16 @@ def updateUandA(feed):
 class Feed(DDBObject):
     def __init__(self,url, initiallyAutoDownloadable=True):
         DDBObject.__init__(self, add=False)
+
+        self.autoDownloadable = initiallyAutoDownloadable
+        self.getEverything = False
+        self.maxNew = -1
+        self.expire = "system"
+        self.expireTime = None
+        self.fallBehind = -1
+
         self.origURL = url
         self.errorState = False
-        self.initiallyAutoDownloadable = initiallyAutoDownloadable
         self.loading = True
         self.actualFeed = FeedImpl(url,self)
         self.download = None
@@ -715,6 +616,67 @@ class Feed(DDBObject):
     def unsetTitle(self):
         self.setTitle(None)
 
+    ##
+    # Switch the auto-downloadable state
+    def setAutoDownloadable(self, automatic):
+        self.confirmDBThread()
+        auto = set()
+        for item in self.items:
+            if item.isEligibleForAutoDownload():
+                auto.add(item)
+        self.autoDownloadable = (automatic == "1")
+        if self.autoDownloadable:
+            for item in self.items:
+                if item.eligibleForAutoDownload:
+                    item.eligibleForAutoDownload = False
+                    item.signalChange()
+        for item in self.items:
+            if item.isEligibleForAutoDownload() or item in auto:
+                item.signalChange(needsSave=False)
+        self.signalChange()
+
+    ##
+    # Sets the 'getEverything' attribute, True or False
+    def setGetEverything(self, everything):
+        self.confirmDBThread()
+        wereAuto = set()
+        for item in self.items:
+            if item.isEligibleForAutoDownload():
+                wereAuto.add(item)
+        self.getEverything = everything
+        self.signalChange()
+        self.signalAutoItems(wereAuto)
+
+    ##
+    # Sets the expiration attributes. Valid types are 'system', 'feed' and 'never'
+    # Expiration time is in hour(s).
+    def setExpiration(self, type, time):
+        self.confirmDBThread()
+        self.expire = type
+        self.expireTime = timedelta(hours=time)
+
+        if self.expire == "never":
+            for item in self.items:
+                if item.isDownloaded():
+                    item.save()
+
+        self.signalChange()
+        for item in self.items:
+            item.signalChange(needsSave=False)
+
+    ##
+    # Sets the maxNew attributes. -1 means unlimited.
+    def setMaxNew(self, maxNew):
+        self.confirmDBThread()
+        oldMaxNew = self.maxNew
+        self.maxNew = maxNew
+        self.signalChange()
+#        for item in self.items:
+#            item.signalChange(needsSave=False)
+        if self.maxNew >= oldMaxNew or self.maxNew < 0:
+            import autodler
+            autodler.autoDownloader.startDownloads()
+
     def makeContextMenu(self, templateName, view):
         items = [
             (self.update, _('Update Channel Now')),
@@ -735,7 +697,7 @@ class Feed(DDBObject):
             if self.idExists() and dialog.choice == dialogs.BUTTON_OK:
                 self.setTitle(dialog.value)
         dialogs.TextEntryDialog(title, text, dialogs.BUTTON_OK,
-            dialogs.BUTTON_CANCEL).run(callback)
+            dialogs.BUTTON_CANCEL, prefillCallback=lambda:self.getTitle()).run(callback)
 
     def update(self):
         self.confirmDBThread()
@@ -766,8 +728,7 @@ class Feed(DDBObject):
             self.folder_id = None
         self.signalChange()
         for item in self.items:
-            item.signalChange(needsSave=False, needsUpdateUandA=False,
-                    needsUpdateXML=False)
+            item.signalChange(needsSave=False, needsUpdateXML=False)
         if newFolder:
             newFolder.signalChange(needsSave=False)
         if oldFolder:
@@ -931,7 +892,7 @@ class Feed(DDBObject):
             self.errorState = False
         else:
             self.errorState = True
-        self.ufeed.signalChange()
+        self.signalChange()
 
     def askForScrape(self, info, initialHTML, charset):
         title = _("Channel is not compatible with Democracy!")
@@ -987,9 +948,9 @@ Democracy.\n\nDo you want to try to load this channel anyway?"""))
 
     def getThumbnail(self):
         self.confirmDBThread()
-        if self.iconCache.isValid():
+        if self.iconCache and self.iconCache.isValid():
             basename = os.path.basename(self.iconCache.getFilename())
-            return resource.iconCacheUrl(basename)
+            return resources.iconCacheUrl(basename)
         else:
             return defaultFeedIconURL()
 
@@ -997,7 +958,7 @@ Democracy.\n\nDo you want to try to load this channel anyway?"""))
         self.confirmDBThread()
         if self.iconCache.isValid():
             basename = os.path.basename(self.iconCache.getFilename())
-            return resource.iconCacheUrl(basename)
+            return resources.iconCacheUrl(basename)
         else:
             return defaultFeedIconURLTablist()
 
@@ -1100,7 +1061,6 @@ class RSSFeedImpl(FeedImpl):
             return ""
 
     def feedparser_finished (self):
-        self.updateUandA(False)
         self.updating = False
         self.ufeed.signalChange(needsSave=False)
         self.scheduleUpdateEvents(-1)
@@ -1138,7 +1098,7 @@ class RSSFeedImpl(FeedImpl):
                 raise
             self.feedparser_finished()
         else:
-            eventloop.callInThread (self.feedparser_callback, self.feedparser_errback, feedparser.parse, html)
+            eventloop.callInThread (self.feedparser_callback, self.feedparser_errback, feedparser.parse, "Feedparser callback - %s" % self.url, html)
 
     ##
     # Updates a feed
@@ -1235,12 +1195,22 @@ class RSSFeedImpl(FeedImpl):
             self.thumbURL = self.parsed.feed.image.url
             self.ufeed.iconCache.requestUpdate(is_vital=True)
         items_byid = {}
+        items_byURLTitle = {}
         items_nokey = []
         for item in self.items:
             try:
                 items_byid[item.getRSSID()] = item
             except KeyError:
                 items_nokey.append (item)
+            entry = item.getRSSEntry()
+            videoEnc = getFirstVideoEnclosure(entry)
+            if videoEnc is not None:
+                entryURL = videoEnc.get('url')
+            else:
+                entryURL = None
+            title = entry.get("title")
+            if title is not None or entryURL is not None:
+                items_byURLTitle[(entryURL, title)] = item
         for entry in self.parsed.entries:
             entry = self.addScrapedThumbnail(entry)
             new = True
@@ -1251,6 +1221,19 @@ class RSSFeedImpl(FeedImpl):
                     if not _entry_equal(entry, item.getRSSEntry()):
                         self._handleNewEntryForItem(item, entry)
                     new = False
+            if new:
+                videoEnc = getFirstVideoEnclosure(entry)
+                if videoEnc is not None:
+                    entryURL = videoEnc.get('url')
+                else:
+                    entryURL = None
+                title = entry.get("title")
+                if title is not None or entryURL is not None:
+                    if items_byURLTitle.has_key ((entryURL, title)):
+                        item = items_byURLTitle[(entryURL, title)]
+                        if not _entry_equal(entry, item.getRSSEntry()):
+                            self._handleNewEntryForItem(item, entry)
+                        new = False
             if new:
                 for item in items_nokey:
                     if _entry_equal(entry, item.getRSSEntry()):
@@ -1258,7 +1241,7 @@ class RSSFeedImpl(FeedImpl):
                     else:
                         try:
                             if _entry_equal (entry["enclosures"], item.getRSSEntry()["enclosures"]):
-                                self._handleNewEntryForItem(entry)
+                                self._handleNewEntryForItem(item, entry)
                                 new = False
                         except:
                             pass
@@ -1273,17 +1256,19 @@ class RSSFeedImpl(FeedImpl):
         
         if self.initialUpdate:
             self.initialUpdate = False
-            self.startfrom = datetime.min
-            itemsToSignal = []
+            startfrom = None
+            itemToUpdate = None
             for item in self.items:
                 itemTime = item.getPubDateParsed()
-                if itemTime > self.startfrom:
-                    self.startfrom = itemTime
-                    itemsToSignal = [item]
-                elif itemTime == self.startfrom:
-                    itemsToSignal.append (item)
-            for item in itemsToSignal:
-                item.signalChange(needsSave=False)
+                if startfrom is None or itemTime > startfrom:
+                    startfrom = itemTime
+                    itemToUpdate = item
+            for item in self.items:
+                if item == itemToUpdate:
+                    item.eligibleForAutoDownload = True
+                else:
+                    item.eligibleForAutoDownload = False
+                item.signalChange()
             self.ufeed.signalChange()
 
     def addScrapedThumbnail(self,entry):
@@ -1463,6 +1448,7 @@ class ScraperFeedImpl(FeedImpl):
         for item in self.items:
             if item.getURL() == link:
                 return
+        title = feedparser.sanitizeHTML (title, "utf-8")
         if dict.has_key('thumbnail') > 0:
             i=Item(FeedParserDict({'title':title,'enclosures':[FeedParserDict({'url':link,'thumbnail':FeedParserDict({'url':dict['thumbnail']})})]}),linkNumber = linkNumber, feed_id=self.ufeed.id)
         else:
@@ -1470,7 +1456,6 @@ class ScraperFeedImpl(FeedImpl):
         if self.ufeed.searchTerm is not None and not filters.matchingItems(i, self.ufeed.searchTerm):
             i.remove()
             return
-        updateUandA(self.ufeed)
 
     #FIXME: compound names for titles at each depth??
     def processLinks(self,links, depth = 0,linkNumber = 0):
@@ -1663,6 +1648,8 @@ class DirectoryFeedImpl(FeedImpl):
     def update(self):
         self.ufeed.confirmDBThread()
         moviesDir = config.get(prefs.MOVIES_DIRECTORY)
+        dirs = [moviesDir] + config.getList(prefs.MY_COLLECTION_DIRS)
+        print dirs
         # Files known about by real feeds
         knownFiles = set()
         for item in views.toplevelItems:
@@ -1683,15 +1670,16 @@ class DirectoryFeedImpl(FeedImpl):
 
         myFiles = set(x.getFilename() for x in self.items)
 
-        #Adds any files we don't know about
-        #Files on the filesystem
-        if os.path.isdir(moviesDir):
-            existingFiles = [os.path.normcase(os.path.join(moviesDir, f)) 
-                    for f in os.listdir(moviesDir)]
-            for file in existingFiles:
-                if (os.path.exists(file) and os.path.basename(file)[0] != '.' and 
-                        not file in knownFiles and not file in myFiles):
-                    FileItem(file, feed_id = self.ufeed.id)
+        for dir in dirs:
+            #Adds any files we don't know about
+            #Files on the filesystem
+            if os.path.isdir(dir):
+                existingFiles = [os.path.normcase(os.path.join(dir, f)) 
+                        for f in os.listdir(dir)]
+                for file in existingFiles:
+                    if (os.path.exists(file) and os.path.basename(file)[0] != '.' and 
+                            not file in knownFiles and not file in myFiles):
+                        FileItem(file, feed_id = self.ufeed.id)
 
         for item in self.items:
             if not os.path.exists(item.getFilename()):
@@ -1712,10 +1700,13 @@ class SearchFeedImpl (RSSFeedImpl):
     
     def __init__(self, ufeed):
         RSSFeedImpl.__init__(self, url='', ufeed=ufeed, title='dtv:search', visible=False)
+        self.initialUpdate = True
         self.setUpdateFrequency(-1)
         self.searching = False
-        self.lastEngine = 'yahoo'
+        self.lastEngine = 'youtube'
         self.lastQuery = ''
+        self.ufeed.autoDownloadable = False
+        self.ufeed.signalChange()
 
     def quoteLastQuery(self):
         return escape(self.lastQuery)
@@ -1723,6 +1714,9 @@ class SearchFeedImpl (RSSFeedImpl):
     def getURL(self):
         return 'dtv:search'
 
+    def getTitle(self):
+        return _('Search')
+
     def getStatus(self):
         status = 'idle-empty'
         if self.searching:
@@ -1751,6 +1745,7 @@ class SearchFeedImpl (RSSFeedImpl):
         url = searchengines.getRequestURL(engine, query)
         self.reset(url, True)
         self.lastQuery = query
+        self.lastEngine = engine
         self.update()
         self.ufeed.signalChange()
 
@@ -1778,6 +1773,9 @@ class SearchDownloadsFeedImpl(FeedImpl):
                 title=None, visible=False)
         self.setUpdateFrequency(-1)
 
+    def getTitle(self):
+        return _('Search')
+
 class ManualFeedImpl(FeedImpl):
     """Videos/Torrents that have been added using by the user opening them
     with democracy.
@@ -1786,9 +1784,12 @@ class ManualFeedImpl(FeedImpl):
     def __init__(self, ufeed):
         FeedImpl.__init__(self, url='dtv:manualFeed', ufeed=ufeed, 
                 title=None, visible=False)
-        self.expire = 'never'
+        self.ufeed.expire = 'never'
         self.setUpdateFrequency(-1)
 
+    def getTitle(self):
+        return _('Local File')
+
 ##
 # Parse HTML document and grab all of the links and their title
 # FIXME: Grab link title from ALT tags in images
@@ -1812,35 +1813,30 @@ class HTMLLinkGrabber(HTMLParser):
             try:
                 linkURL = match.group(3).encode('ascii')
             except UnicodeError:
-#                i = len (linkURL)
-#                while (i >= 0):
-#                    if 127 < linkURL[i] <= 255:
-#                        linkURL[i:i+1] = "%%%02x" % (ord(linkURL[i]))
-#                    else if linkURL[i] > 255:
-#                        print "WARNING: scraped URL is non-ascii (%s)-- discarding" \
-#                              % match.group(3)
-#                        break
-#                    i = i - 1
-                if util.chatter:
-                    print "WARNING: scraped URL is non-ascii (%s)-- discarding (baseURL=%s)" \
-                            % (match.group(3), self.baseurl)
-            else:
-                link = urljoin(baseurl, linkURL)
-                desc = match.group(4)
-                imgMatch = HTMLLinkGrabber.imgPattern.match(desc)
-                if imgMatch:
-                    try:
-                        thumb = urljoin(baseurl,
-                                imgMatch.group(1).encode('ascii'))
-                    except UnicodeError:
-                        if util.chatter:
-                            print ("WARNING: scraped thumbnail url is non-ascii "
-                            "(%s) -- discarding"  % imgMatch.group(1))
-                        thumb = None
-                else:
+                linkURL = match.group(3)
+                print "%s is non-ascii, trying anyway: (baseURL: %s)" % (linkURL.decode("latin1"), self.baseurl)
+                i = len (linkURL) - 1
+                while (i >= 0):
+                    if 127 < ord(linkURL[i]) <= 255:
+                        linkURL = linkURL[:i] + "%%%02x" % (ord(linkURL[i])) + linkURL[i+1:]
+                    i = i - 1
+
+            link = urljoin(baseurl, linkURL)
+            desc = match.group(4)
+            imgMatch = HTMLLinkGrabber.imgPattern.match(desc)
+            if imgMatch:
+                try:
+                    thumb = urljoin(baseurl,
+                            imgMatch.group(1).encode('ascii'))
+                except UnicodeError:
+                    if util.chatter:
+                        print ("WARNING: scraped thumbnail url is non-ascii "
+                        "(%s) -- discarding"  % imgMatch.group(1))
                     thumb = None
-                desc =  HTMLLinkGrabber.tagPattern.sub(' ',desc)
-                self.links.append((link, desc, thumb))
+            else:
+                thumb = None
+            desc =  HTMLLinkGrabber.tagPattern.sub(' ',desc)
+            self.links.append((link, desc, thumb))
             match = HTMLLinkGrabber.linkPattern.search(match.group(5))
         return self.links
 
@@ -1867,7 +1863,7 @@ class RSSLinkGrabber(xml.sax.handler.ContentHandler):
         tag = name[1]
         if self.firstTag:
             self.firstTag = False
-            if tag != 'rss':
+            if tag not in ['rss','feed']:
                 raise xml.sax.SAXNotRecognizedException, "Not an RSS file"
         if tag.lower() == 'enclosure' or tag.lower() == 'content':
             self.enclosureCount += 1
