@@ -1,4 +1,4 @@
-import resource
+import resources
 from database import DDBObject
 from template import fillStaticTemplate
 from httpclient import grabURL
@@ -54,10 +54,6 @@ class ChannelGuide(DDBObject):
     def __init__(self, url=None):
         # Delayed callback for eventloop.
         self.dc = None
-        # True if user has seen the tutorial, or this is a non default guide.
-        # We don't want to display the Intro anymore.
-        self.sawIntro = True
-#        self.sawIntro = url != None
         # If None, we have never successfully loaded the guide. Otherwise,
         # the <body> part of the front channel guide page from the last time
         # we loaded it, whenever that was (perhaps in a previous session.)
@@ -69,7 +65,10 @@ class ChannelGuide(DDBObject):
         # None means this is the default channel guide.
         self.url = url
 
-        self.redirectedURL = None
+        if url is None:
+            self.redirectedURL = config.get(prefs.CHANNEL_GUIDE_URL)
+        else:
+            self.redirectedURL = url
 
         DDBObject.__init__(self)
         # Start loading the channel guide.
@@ -100,10 +99,6 @@ class ChannelGuide(DDBObject):
             # Uses precaching. Set up an initial update, plus hourly reloads..
             self.startUpdates()
 
-    def setSawIntro(self):
-        self.sawIntro = True
-        self.signalChange()
-
     def startUpdates(self):
         if not self.dc:
             self.dc = eventloop.addIdle (self.update, "Channel Guide Update")
@@ -113,9 +108,6 @@ class ChannelGuide(DDBObject):
     # If scheme is 'template', value is the template that should be loaded in
     # the frame.
     def getLocation(self):
-        if not self.sawIntro:
-            return ('template', 'first-time-intro')
-
         import frontend
         apiurl = frontend.getDTVAPIURL()
         if apiurl:
@@ -157,7 +149,7 @@ class ChannelGuide(DDBObject):
 
             #print "DTV: No guide available! Sending apology instead."
             self.startUpdates()
-            return fillStaticTemplate("go-to-guide", platform="", eventCookie="", id=self.getID())
+            return fillStaticTemplate("go-to-guide", 'default', platform="", eventCookie="", id=self.getID())
         else:
             return self.cachedGuideBody
 
@@ -228,7 +220,7 @@ class ChannelGuide(DDBObject):
             return self.getURL()
 
     def getIconURL(self):
-        return resource.url("images/channelguide-icon-tablist.png")
+        return resources.url("images/channelguide-icon-tablist.png")
 
 def getGuideByURL(url):
     return views.guides.getItemWithIndex(indexes.guidesByURL, url)
