@@ -8,9 +8,32 @@ from download_utils import nextFreeFilename, shortenFilename
 import config
 import prefs
 import time
+import views
+import random
 
 RUNNING_MAX = 3
 
+def clearOrphans():
+    knownIcons = set()
+    for item in views.items:
+        if item.iconCache and item.iconCache.filename:
+            knownIcons.add(os.path.normcase(item.iconCache.filename))
+    for feed in views.feeds:
+        if feed.iconCache and feed.iconCache.filename:
+            knownIcons.add(os.path.normcase(feed.iconCache.filename))
+    cachedir = config.get(prefs.ICON_CACHE_DIRECTORY)
+    if os.path.isdir(cachedir):
+        existingFiles = [os.path.normcase(os.path.join(cachedir, f)) 
+                for f in os.listdir(cachedir)]
+        for file in existingFiles:
+            if (os.path.exists(file) and os.path.basename(file)[0] != '.' and 
+                    not file in knownIcons):
+                try:
+                    os.remove (file)
+                except OSError:
+                    pass
+    
+
 class IconCacheUpdater:
     def __init__ (self):
         self.idle = LinkedList()
@@ -157,7 +180,16 @@ class IconCache:
                 return
 
             if (self.filename == None):
-                self.filename = os.path.join(cachedir, info["filename"])
+                # Add a random unique id
+                parts = info["filename"].split('.')
+                uid = "%08d" % (random.randint(0,99999999),)
+                if len(parts) == 1:
+                    parts.append(uid)
+                else:
+                    parts[-1:-1] = [uid]
+                self.filename = '.'.join(parts)
+
+                self.filename = os.path.join(cachedir, self.filename)
                 self.filename = shortenFilename (self.filename)
                 self.filename = nextFreeFilename (self.filename)
                 needsSave = True
