@@ -27,7 +27,7 @@ import feed
 import filters
 import menu
 import prefs
-import resource
+import resources
 import views
 import random
 import indexes
@@ -39,11 +39,6 @@ import adscraper
 import re
 HTMLPattern = re.compile("^.*<body.*?>(.*)</body\s*>", re.S)
 
-def updateUandA (feed):
-    # Not toplevel to avoid a dependency loop at load time.
-    import feed as feed_mod
-    feed_mod.updateUandA (feed)
-
 _charset = locale.getpreferredencoding()
 
 class Item(DDBObject):
@@ -65,6 +60,7 @@ class Item(DDBObject):
         self.expired = False
         self.keep = False
         self.videoFilename = ""
+        self.eligibleForAutoDownload = True
 
         self.iconCache = IconCache(self)
         
@@ -78,7 +74,6 @@ class Item(DDBObject):
         self._lookForFinishedDownloader()
         DDBObject.__init__(self)
         self.splitItem()
-        updateUandA(self.getFeed())
 
     ##
     # Called by pickle during serialization
@@ -150,7 +145,7 @@ class Item(DDBObject):
         for video in videos:
             FileItem (video, parent_id=self.id)
         if videos:
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
             return True
         return False
 
@@ -184,7 +179,7 @@ class Item(DDBObject):
         else:
             self.isContainerItem = False
             self.videoFilename = filename_root
-        self.signalChange(needsUpdateUandA=True)
+        self.signalChange()
         return True
 
     def removeFromPlaylists(self):
@@ -235,27 +230,22 @@ class Item(DDBObject):
         if self.parent_id is not None and self.feed_id is not None:
             raise DatabaseConstraintError ("feed_id and parent_id both not None")
 
-    # Unfortunately, our database does not scale well with many views,
-    # so we have this hack to make sure that unwatched and available
-    # get updated when an item changes
-    def signalChange(self, needsSave=True, needsUpdateUandA=False, needsUpdateXML=True):
+    def signalChange(self, needsSave=True, needsUpdateXML=True):
         self.expiring = None
-        if hasattr(self, "_state"):
+        try:
             del self._state
-        if hasattr(self, "_size"):
+        except:
+            pass
+        try:
             del self._size
-        DDBObject.signalChange(self, needsSave=needsSave)
+        except:
+            pass
         if needsUpdateXML:
             try:
                 del self._itemXML
             except:
                 pass
-        if needsUpdateUandA:
-            try:
-                # If the feed has been deleted, getFeed will throw an exception
-                updateUandA(self.getFeed())
-            except:
-                pass
+        DDBObject.signalChange(self, needsSave=needsSave)
 
     # Returns the rendered download-item template, hopefully from the cache
     #
@@ -270,39 +260,20 @@ class Item(DDBObject):
     #     item is in is the view that's selected.  This matters when an item
     #     is shown multiple times on a page, in different views.
     #  * The channel name -- it's not displayed in the channel template.
-    def getItemXML(self, viewName, view, hideChannelTitle=False):
+    def getItemXML(self, viewName):
         try:
             xml = self._itemXML
         except AttributeError:
-            self._calcItemXML(view)
+            self._calcItemXML()
             xml = self._itemXML
-        if viewName == 'playlistView':
-            dragDestType = 'downloadeditem'
-        else:
-            dragDestType = ''
-        if hideChannelTitle:
-            channelTitle = ''
-        else:
-            implClass = self.getFeed().actualFeed.__class__
-            if implClass in (feed.RSSFeedImpl, feed.ScraperFeedImpl):
-                channelTitle = self.getFeed().getTitle()
-            else:
-                channelTitle = ''
-        for old, new in [
-            (self._XMLViewName, viewName),
-            ("---DRAGDESTTYPE---", dragDestType),
-            ("---SELECTEDSTATE---", self.getSelectedState(view)),
-            ("---CHANNELTITLE---", channelTitle),
-        ]:
-                xml = xml.replace(old, new)
-        return xml
+        return xml.replace(self._XMLViewName, viewName)
 
     # Regenerates an expired item XML from the download-item template
     # _XMLViewName is a random string we use for the name of the view
     # _itemXML is the rendered XML
-    def _calcItemXML(self, view):
+    def _calcItemXML(self):
         self._XMLViewName = "view%dview" % random.randint(9999999,99999999)
-        self._itemXML = HTMLPattern.match(template.fillStaticTemplate('download-item','unknown','noCookie', '', this=self, viewName = self._XMLViewName)).group(1)
+        self._itemXML = HTMLPattern.match(template.fillStaticTemplate('download-item-inner','unknown','noCookie', '', this=self, viewName = self._XMLViewName)).group(1)
 
     #
     # Returns True iff this item has never been viewed in the interface
@@ -394,7 +365,6 @@ class Item(DDBObject):
     ##
     # Moves this item to another feed.
     def setFeed(self, feed_id):
-        updateUandA(self.getFeed())
         self.feed_id = feed_id
         del self._feed
         if self.isContainerItem:
@@ -402,13 +372,12 @@ class Item(DDBObject):
                 del item._feed
                 item.signalChange()
         self.signalChange()
-        updateUandA(self.getFeed())
 
     def executeExpire(self):
         self.confirmDBThread()
         self.removeFromPlaylists()
         UandA = self.getUandA()
-        self.deleteFile()
+        self.deleteFiles()
         self.expired = True
         if self.isContainerItem:
             for item in self.getChildren():
@@ -417,7 +386,7 @@ class Item(DDBObject):
         self.seen = self.keep = self.pendingManualDL = False
         self.watchedTime = None
         if self.getFeedURL() != "dtv:manualFeed":
-            self.signalChange(needsUpdateUandA = (UandA != self.getUandA()))
+            self.signalChange()
         else:
             self.remove()
 
@@ -427,8 +396,8 @@ class Item(DDBObject):
         if self.isContainerItem:
             title = _("Deleting %s") % (os.path.basename(self.getTitle()))
             description = _("""\
-This item is a folder.  When you delete a folder, any items inside that \
-folder will also be deleted.""")
+This item is a folder.  When you remove a folder, any items inside that \
+folder will be deleted.""")
             d = dialogs.ChoiceDialog(title, description,
                                      dialogs.BUTTON_DELETE_FILES,
                                      dialogs.BUTTON_CANCEL)
@@ -479,7 +448,7 @@ folder will also be deleted.""")
 
     def getUandA(self):
         """Get whether this item is new, or newly-downloaded, or neither."""
-        state = self.getEmblemCSSClass()
+        state = self.getState()
         if state == 'new':
             return (0, 1)
         elif state == 'newly-downloaded':
@@ -560,13 +529,13 @@ folder will also be deleted.""")
             if self.watchedTime is None:
                 self.watchedTime = datetime.now()
             self.clearParentsChildrenSeen()
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
 
     def clearParentsChildrenSeen(self):
         if self.parent_id:
             parent = self.getParent()
             parent.childrenSeen = None
-            parent.signalChange(needsUpdateUandA=True)
+            parent.signalChange()
 
     def markItemUnseen(self):
         self.confirmDBThread()
@@ -583,7 +552,6 @@ folder will also be deleted.""")
             self.watchedTime = None
             self.clearParentsChildrenSeen()
             self.signalChange()
-        updateUandA(self.getFeed())
 
     def getRSSID(self):
         self.confirmDBThread()
@@ -599,7 +567,7 @@ folder will also be deleted.""")
         self.confirmDBThread()
         if autodl != self.autoDownloaded:
             self.autoDownloaded = autodl
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
 
     def getPendingReason(self):
         self.confirmDBThread()
@@ -628,7 +596,7 @@ folder will also be deleted.""")
                 manualDownloadCount >= config.get(prefs.MAX_MANUAL_DOWNLOADS)):
             self.pendingManualDL = True
             self.pendingReason = "queued for download"
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
             return
         else:
             self.setAutoDownloaded(autodl)
@@ -640,7 +608,7 @@ folder will also be deleted.""")
             self.onDownloadFinished()
         else:
             self.downloader.start()
-        self.signalChange(needsUpdateUandA=True)
+        self.signalChange()
 
     def isPendingManualDownload(self):
         self.confirmDBThread()
@@ -656,8 +624,7 @@ folder will also be deleted.""")
         ufeed = self.getFeed()
         if ufeed.getEverything:
             return True
-        pubDate = self.getPubDateParsed()
-        return pubDate >= ufeed.startfrom and pubDate != datetime.max
+        return self.eligibleForAutoDownload
 
     def isPendingAutoDownload(self):
         return (self.getFeed().isAutoDownloadable() and
@@ -693,11 +660,11 @@ folder will also be deleted.""")
         self.confirmDBThread()
         if self.iconCache.isValid():
             basename = os.path.basename(self.iconCache.getFilename())
-            return resource.iconCacheUrl(basename)
+            return resources.iconCacheUrl(basename)
         elif self.isContainerItem:
-            return resource.url("images/container-icon.png")
+            return resources.url("images/container-icon.png")
         else:
-            return resource.url("images/thumb.png")
+            return resources.url("images/thumb.png")
     ##
     # returns the title of the item
     def getTitle(self):
@@ -710,6 +677,13 @@ folder will also be deleted.""")
             except:
                 return ""
 
+    def getChannelTitle(self):
+        implClass = self.getFeed().actualFeed.__class__
+        if implClass in (feed.RSSFeedImpl, feed.ScraperFeedImpl):
+            return self.getFeed().getTitle()
+        else:
+            return ''
+
     ##
     # Returns the raw description of the video
     def getRawDescription(self):
@@ -729,7 +703,7 @@ folder will also be deleted.""")
         rawDescription = self.getRawDescription()
         try:
             purifiedDescription = adscraper.purify(rawDescription)
-            return xhtmlify ('<span>%s</span>' % (unescape(purifiedDescription),))
+            return xhtmlify ('<span>%s</span>' % (unescape(purifiedDescription),), filterFontTags=True)
         except:
             try:
                 return xhtmlify ('<span>%s</span>' % (unescape(rawDescription),))
@@ -782,12 +756,12 @@ folder will also be deleted.""")
 
     ##
     # Stops downloading the item
-    def deleteFile(self):
+    def deleteFiles(self):
         self.confirmDBThread()
         if self.downloader is not None:
             self.downloader.removeItem(self)
             self.downloader = None
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
 
     def getState(self):
         """Get the state of this item.  The state will be on of the following:
@@ -875,8 +849,10 @@ folder will also be deleted.""")
         return self.getState() in ("newly-downloaded", "expiring", "saved")
 
     def showSaveButton(self):
-        return (self.getState() in ('newly-downloaded', 'expiring') and
-                self.getExpirationTime() is not None)
+        return self.getState() in ('newly-downloaded', 'expiring') and not self.keep
+
+    def showSaved(self):
+        return self.getState() in ('saved',) or (self.getState() in ('newly-downloaded', 'expiring') and self.keep)
 
     def showTrashButton(self):
         return self.isDownloaded() or (self.getFeedURL() == 'dtv:manualFeed'
@@ -1206,7 +1182,7 @@ folder will also be deleted.""")
             self.updateReleaseDate()
             self._calcFirstEnc()
         finally:
-            self.signalChange(needsUpdateUandA = (UandA != self.getUandA()))
+            self.signalChange()
 
     def onDownloadFinished(self):
         """Called when the download for this item finishes."""
@@ -1214,7 +1190,7 @@ folder will also be deleted.""")
         self.confirmDBThread()
         self.downloadedTime = datetime.now()
         if not self.splitItem():
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
 
         for other in views.items:
             if other.downloader is None and other.getURL() == self.getURL():
@@ -1228,7 +1204,7 @@ folder will also be deleted.""")
         self.confirmDBThread()
         if self.keep != True:
             self.keep = True
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
 
     ##
     # gets the time the video was downloaded
@@ -1303,11 +1279,8 @@ folder will also be deleted.""")
         if not isinstance (self, FileItem) and self.downloader is None:
             self.downloader = downloader.getExistingDownloader(self)
             if self.downloader is not None:
-                self.signalChange(needsSave=False, needsUpdateUandA=False)
+                self.signalChange(needsSave=False)
         self.splitItem()
-        # Do this here instead of onRestore in case the feed hasn't
-        # been loaded yet.
-        updateUandA(self.getFeed())
         # This must come after reconnecting the downloader
         if self.isContainerItem is not None and not os.path.exists(self.getFilename()):
             self.executeExpire()
@@ -1419,7 +1392,7 @@ class FileItem(Item):
         else:
             # external item that the user deleted in DP
             self.deleted = True
-            self.signalChange(needsUpdateUandA=True)
+            self.signalChange()
 
     def expire(self):
         if not self.isExternal():
@@ -1548,7 +1521,7 @@ any items inside that folder will also be removed or deleted.""")
     def callback(dialog):
         if dialog.choice == dialogs.BUTTON_DELETE_FILES:
             for item in items:
-                if item.idExists():
+                if item.idExists() and isinstance (item, FileItem):
                     item.deleteFiles()
         if dialog.choice in (dialogs.BUTTON_OK, dialogs.BUTTON_REMOVE_ENTRY,
                 dialogs.BUTTON_DELETE_FILES):
