@@ -29,6 +29,7 @@ BT_MAX_PORT                 = Pref( key='BitTorrentMaxPort',     default=8600,
 UPLOAD_RATIO                = Pref( key='uploadRatio',           default=2.0,   platformSpecific=False )
 STARTUP_TASKS_DONE          = Pref( key='startupTasksDone',      default=False, platformSpecific=False )
 SINGLE_VIDEO_PLAYBACK_MODE  = Pref( key='singleVideoPlaybackMode', default=False, platformSpecific=False )
+MY_COLLECTION_DIRS          = Pref( key="CollectionDirs",        default="",    platformSpecific=False )
 
 # These have a hardcoded default which can be overridden by setting an
 # environment variable.
@@ -82,18 +83,20 @@ GETTEXT_PATHNAME = \
 
 # These are normally read from resources/app.config.
 SHORT_APP_NAME = \
-    Pref(key='shortAppName', default=None, platformSpecific=False)
+    Pref(key='shortAppName',      default=None, platformSpecific=False)
 LONG_APP_NAME = \
-    Pref(key='longAppName',  default=None, platformSpecific=False)
+    Pref(key='longAppName',       default=None, platformSpecific=False)
 PROJECT_URL = \
-    Pref(key='projectURL',   default=None, platformSpecific=False)
+    Pref(key='projectURL',        default=None, platformSpecific=False)
 PUBLISHER = \
-    Pref(key='publisher',    default=None, platformSpecific=False)
+    Pref(key='publisher',         default=None, platformSpecific=False)
 APP_VERSION = \
-    Pref(key='appVersion',   default=None, platformSpecific=False)
+    Pref(key='appVersion',        default=None, platformSpecific=False)
 APP_REVISION = \
-    Pref(key='appRevision',  default=None, platformSpecific=False)
+    Pref(key='appRevision',       default=None, platformSpecific=False)
 APP_PLATFORM = \
-    Pref(key='appPlatform',  default=None, platformSpecific=False)
+    Pref(key='appPlatform',       default=None, platformSpecific=False)
 APP_SERIAL = \
-    Pref(key='appSerial-unknown',    default="0", platformSpecific=False)
+    Pref(key='appSerial-unknown', default="0",  platformSpecific=False)
+MOZILLA_LIB_PATH = \
+    Pref(key='mozillaLibPath',    default=None, platformSpecific=False)
