@@ -230,6 +230,7 @@ class ItemSchema(DDBObjectSchema):
         ('isContainerItem', SchemaBool(noneOk=True)),
         ('videoFilename', SchemaString()),
         ('releaseDateObj', SchemaDateTime()),
+        ('eligibleForAutoDownload', SchemaBool()),
     ]
 
 class FileItemSchema(ItemSchema):
@@ -247,13 +248,18 @@ class FeedSchema(DDBObjectSchema):
     fields = DDBObjectSchema.fields + [
         ('origURL', SchemaString()),
         ('errorState', SchemaBool()),
-        ('initiallyAutoDownloadable', SchemaBool()),
         ('loading', SchemaBool()),
         ('actualFeed', SchemaObject(FeedImpl)),
         ('iconCache', SchemaObject(IconCache, noneOk=True)),
         ('folder_id', SchemaInt(noneOk=True)),
         ('searchTerm', SchemaString(noneOk=True)),
         ('userTitle', SchemaString(noneOk=True)),
+        ('autoDownloadable', SchemaBool()),
+        ('getEverything', SchemaBool()),
+        ('maxNew', SchemaInt()),
+        ('fallBehind', SchemaInt()),
+        ('expire', SchemaString()),
+        ('expireTime', SchemaTimeDelta(noneOk=True)),
     ]
 
 class FeedImplSchema(ObjectSchema):
@@ -264,17 +270,10 @@ class FeedImplSchema(ObjectSchema):
         ('ufeed', SchemaObject(Feed)),
         ('title', SchemaString()),
         ('created', SchemaDateTime()),
-        ('autoDownloadable', SchemaBool()),
-        ('startfrom', SchemaDateTime()),
-        ('getEverything', SchemaBool()),
-        ('maxNew', SchemaInt()),
-        ('fallBehind', SchemaInt()),
-        ('expire', SchemaString()),
         ('visible', SchemaBool()),
         ('lastViewed', SchemaDateTime()),
         ('thumbURL', SchemaString(noneOk=True)),
         ('updateFreq', SchemaInt()),
-        ('expireTime', SchemaTimeDelta(noneOk=True)),
         ('initialUpdate', SchemaBool()),
     ]
 
@@ -381,13 +380,12 @@ class ChannelGuideSchema(DDBObjectSchema):
     klass = ChannelGuide
     classString = 'channel-guide'
     fields = DDBObjectSchema.fields + [
-        ('sawIntro', SchemaBool()),
         ('cachedGuideBody', SchemaString(noneOk=True)),
         ('url', SchemaString(noneOk=True)),
         ('redirectedURL', SchemaString(noneOk=True)),
     ]
 
-VERSION = 24
+VERSION = 30
 objectSchemas = [ 
     DDBObjectSchema, IconCacheSchema, ItemSchema, FileItemSchema, FeedSchema,
     FeedImplSchema, RSSFeedImplSchema, ScraperFeedImplSchema,
