@@ -427,7 +427,8 @@ class SelectionHandler(object):
         elif len(tls.currentSelection) == 1:
             for id in tls.currentSelection:
                 tab = tls.currentView.getObjectByID(id)
-                return app.TemplateDisplay(tab.contentsTemplate, 
+                return app.TemplateDisplay(tab.contentsTemplate,
+                                           tab.templateState,
                         frameHint=frame, areaHint=frame.mainDisplay, 
                         id=tab.obj.getID())
         else:
@@ -450,7 +451,7 @@ class SelectionHandler(object):
                             selectedChildren -= 1
                 else:
                     selectedChildren += 1
-            return app.TemplateDisplay(templateName, frameHint=frame,
+            return app.TemplateDisplay(templateName,'default', frameHint=frame,
                     areaHint=frame.mainDisplay,
                     selectedFolders=selectedFolders,
                     selectedChildren=selectedChildren,
@@ -539,12 +540,28 @@ class SelectionHandler(object):
                 guideURL, videoFileName)
 
     def displayCurrentTabContent(self):
+        frame = app.controller.frame
+        mainDisplay = frame.getDisplay(frame.mainDisplay)
+
+        # Hack to avoid re-displaying channel template
+        if (mainDisplay and hasattr(mainDisplay, 'templateName') and mainDisplay.templateName == 'channel'):
+            tls = self.tabListSelection
+            if len(tls.currentSelection) == 1:
+                for id in tls.currentSelection:
+                    tab = tls.currentView.getObjectByID(id)
+                    if tab.contentsTemplate == 'channel':
+                        newId = int(tab.obj.getID())
+                        #print "swapping templates %d %d" % (mainDisplay.kargs['id'], newId)
+                                                        
+                        self.itemListSelection.clearSelection()
+                        self.updateMenus()
+                        mainDisplay.reInit(id = newId)
+                        return
         newDisplay = self._chooseDisplayForCurrentTab()
+
         # Don't redisplay the current tab if it's being displayed.  It messes
         # up our database callbacks.  The one exception is the guide tab,
         # where redisplaying it will reopen the home page.
-        frame = app.controller.frame
-        mainDisplay = frame.getDisplay(frame.mainDisplay) 
         if (self.lastDisplay and newDisplay == self.lastDisplay and
                 self.lastDisplay is mainDisplay and
                 newDisplay.templateName != 'guide'):
