@@ -5,7 +5,7 @@ import views
 import eventloop
 import feed
 import folder
-import resource
+import resources
 import guide
 import playlist
 import sorts
@@ -35,17 +35,18 @@ class StaticTab(database.DDBObject):
         'downloadtab': 'download-icon-tab.png',
     }
 
-    def __init__(self, tabTemplateBase, contentsTemplate, order):
+    def __init__(self, tabTemplateBase, contentsTemplate, state, order):
         self.tabTemplateBase = tabTemplateBase
         self.contentsTemplate = contentsTemplate
         self.order = order
+        self.templateState = state
         database.DDBObject.__init__(self)
 
     def getTitle(self):
         return self.tabTitles[self.tabTemplateBase]
 
     def getIconURL(self):
-        return resource.url("images/%s" % self.tabIcons[self.tabTemplateBase])
+        return resources.url("images/%s" % self.tabIcons[self.tabTemplateBase])
 
     def getNumberColor(self):
         if self.tabTemplateBase == 'downloadtab':
@@ -70,9 +71,10 @@ class StaticTab(database.DDBObject):
 class Tab:
     idCounter = 0
 
-    def __init__(self, tabTemplateBase, contentsTemplate, sortKey, obj):
+    def __init__(self, tabTemplateBase, contentsTemplate, templateState, sortKey, obj):
         self.tabTemplateBase = tabTemplateBase
         self.contentsTemplate = contentsTemplate
+        self.templateState = templateState
         self.sortKey = sortKey
         self.display = None
         self.id = "tab%d" % Tab.idCounter
@@ -298,9 +300,10 @@ def reloadStaticTabs():
 
     # Load them anew from the resource file.
     # NEEDS: maybe better error reporting?
-    document = parse(resource.path('statictabs.xml'))
+    document = parse(resources.path('statictabs.xml'))
     for n in document.getElementsByTagName('statictab'):
         tabTemplateBase = n.getAttribute('tabtemplatebase')
         contentsTemplate = n.getAttribute('contentstemplate')
+        state = n.getAttribute('state')
         order = int(n.getAttribute('order'))
-        StaticTab(tabTemplateBase, contentsTemplate, order)
+        StaticTab(tabTemplateBase, contentsTemplate, state, order)
