@@ -6,13 +6,14 @@ import os
 import config
 import eventloop
 from templatehelper import quoteattr, escape, attrPattern, rawAttrPattern, resourcePattern, generateId
+from templateoptimize import HTMLChangeOptimizer
 from xhtmltools import urlencode, toUTF8Bytes
 from itertools import chain
 
 if os.environ.has_key('DEMOCRACY_RECOMPILE_TEMPLATES'):
     import template_compiler
-    import resource
-    template_compiler.setResourcePath(resource.path(''))
+    import resources
+    template_compiler.setResourcePath(resources.path(''))
 
 
 ###############################################################################
@@ -28,27 +29,27 @@ if os.environ.has_key('DEMOCRACY_RECOMPILE_TEMPLATES'):
 # from filling the template, and a "template handle" whose
 # unlinkTemplate() method you should call when you no longer want to
 # receive Javascript callbacks.
-def fillTemplate(filename, domHandler, platform, eventCookie, bodyTagExtra="", top = True, onlyBody = False, *args, **kargs):
+def fillTemplate(filename, state, domHandler, platform, eventCookie, bodyTagExtra="", top = True, onlyBody = False, *args, **kargs):
     # FIXME add support for "onlyBody"
     if os.environ.has_key('DEMOCRACY_RECOMPILE_TEMPLATES'):
         (tcc, handle) = template_compiler.compileTemplate(filename)
         exec tcc.getOutput() in locals()
-        return fillTemplate(domHandler, platform, eventCookie, bodyTagExtra, *args, **kargs)
+        return fillTemplate(state, domHandler, platform, eventCookie, bodyTagExtra, *args, **kargs)
     else:
         filename = filename.replace('/','.').replace('\\','.').replace('-','_')
         components = filename.split('.')
         mod = __import__("compiled_templates.%s"%filename)
         for comp in components:
             mod = getattr(mod,comp)
-        return mod.fillTemplate(domHandler, platform, eventCookie, bodyTagExtra, *args, **kargs)
+        return mod.fillTemplate(state, domHandler, platform, eventCookie, bodyTagExtra, *args, **kargs)
 
 # As fillTemplate, but no Javascript calls are made, and no template
 # handle is returned, only the HTML or XML as a string. Effectively,
 # you get a static snapshot of the page at the time the call is made.
-def fillStaticTemplate(filename, platform, eventCookie, bodyTagExtra="", *args, **kargs):
+def fillStaticTemplate(filename, state, platform, eventCookie, bodyTagExtra="", *args, **kargs):
     # FIXME add support for "onlyBody" parameter. See item.py for an
     # example of how we're working around not having that.
-    (tch, handle) = fillTemplate(filename, None, platform, eventCookie, bodyTagExtra, *args, **kargs)
+    (tch, handle) = fillTemplate(filename, state, None, platform, eventCookie, bodyTagExtra, *args, **kargs)
     handle.unlinkTemplate()
     return tch.read()
 
@@ -79,7 +80,6 @@ def queueSelectDisplay(frame, display, area):
     useful if you want it to happen after template DOM updates (see
     selection.py for an example).
     """
-
     toSelect[area] = display
     queueDOMChange(lambda: doSelectDisplay(frame, area), "Select display")
 
@@ -110,12 +110,15 @@ class TrackedView:
         self.view = view.map(IDAssignmentInView(id(self)).mapper)
         self.templateFunc = templateFunc
         self.parent = parent
+        self.htmlChanger = parent.htmlChanger
         self.name = name
         self.toChange = {}
         self.toRemove = []
         self.toAdd = []
         self.addBefore = None
         self.idle_queued = False
+        self.currentAttrs = {}
+        self.currentInnerHTMLs = {}
 
     #
     # This is called after the HTML has been rendered to fill in the
@@ -126,7 +129,7 @@ class TrackedView:
         #start = time.clock()
         xmls = []
         for x in self.view:
-            xmls.append(self.currentXML(x))
+            xmls.append(self.initialXML(x))
         # Web Kit treats adding the empty string like adding "&nbsp;",
         # so we don't add the HTML unless it's non-empty
         if len(xmls) > 0:
@@ -141,24 +144,27 @@ class TrackedView:
         self.view.removeAddCallback(self.onAdd)
         self.view.removeRemoveCallback(self.onRemove)
 
+    def initialXML(self, item):
+        xml = self.currentXML(item)
+        self.htmlChanger.setInitialHTML(item.tid, xml)
+        return xml
+
     def currentXML(self, item):
-        return self.templateFunc(item.object, self.name, self.origView, item.tid).read()
+        xml = self.templateFunc(item.object, self.name, self.origView, item.tid).read()
+        return xml
 
     def callback (self):
         if self.parent.domHandler:
             if len (self.toAdd) > 0:
-                adds = [self.currentXML(obj) for obj in self.toAdd]
+                adds = [self.initialXML(obj) for obj in self.toAdd]
                 addXml = "".join (adds)
                 self.doAdd(addXml)
 
-#            Equivalent code:
-
-#            changes = []
-#            for id in self.toChange:
-#                obj = self.toChange[id]
-#                changes.append( (obj.tid, self.currentXML(obj)) )
-                
-            changes = [(self.toChange[id].tid, self.currentXML(self.toChange[id])) for id in self.toChange]
+            changes = []
+            for id in self.toChange:
+                obj = self.toChange[id]
+                xml = self.currentXML(obj)
+                changes.extend(self.htmlChanger.calcChanges(obj.tid, xml))
             if len(changes) > 0:
                 self.parent.domHandler.changeItems(changes)
 
@@ -174,7 +180,7 @@ class TrackedView:
 
     def addCallback(self):
         if not self.idle_queued:
-            queueDOMChange(self.callback, "Update UI")
+            queueDOMChange(self.callback, "TrackedView DOM Change (%s)" % self.name)
             self.idle_queued = True
 
     def onChange(self,obj,id):
@@ -240,7 +246,7 @@ class TrackedView:
 
 class UpdateRegionBase:
     """Base class for UpdateRegion and ConfigUpdateRegion.  Subclasses must
-    define currentXML, which returns a string representing the up-to-date XML
+    define renderXML, which returns a string representing the up-to-date XML
     for this region.  Also, hookupCallbacks() which hooks up any callbacks
     needed.  Subclasses can use onChange() as the handler for any callbacks.
     """
@@ -253,26 +259,35 @@ class UpdateRegionBase:
 
         self.templateFunc = templateFunc
         self.parent = parent
+        self.htmlChanger = self.parent.htmlChanger
         self.tid = generateId()
         self.idle_queued = False
+        self.currentAttrs = None
+        self.currentInnerHTML = None
 
     #
     # This is called after the HTML has been rendered to fill in the
     # data for each view and register callbacks to keep it updated
     def initialFillIn(self):
         if self.parent.domHandler:
-            self.parent.domHandler.addItemBefore(self.currentXML(), self.anchorId)
+            self.parent.domHandler.addItemBefore(self.initialXML(), self.anchorId)
         self.hookupCallbacks()
 
+    def initialXML(self):
+        xml = self.renderXML()
+        self.htmlChanger.setInitialHTML(self.tid, xml)
+        return xml
+
     def onChange(self, *args, **kwargs):
         if not self.idle_queued:
-            queueDOMChange(self.doChange, "Update UI")
+            queueDOMChange(self.doChange, "UpdateRegion DOM Change (%s)" % self.name)
             self.idle_queued = True
 
     def doChange(self):
-        xmlString = self.currentXML()
-        if self.parent.domHandler:
-            self.parent.domHandler.changeItem(self.tid, xmlString)
+        xml = self.renderXML()
+        changes = self.parent.htmlChanger.calcChanges(self.tid, xml)
+        if changes and self.parent.domHandler:
+            self.parent.domHandler.changeItems(changes)
         self.idle_queued = False
 
 class UpdateRegion(UpdateRegionBase):
@@ -281,7 +296,7 @@ class UpdateRegion(UpdateRegionBase):
         self.view = view
         self.name = name
 
-    def currentXML(self):
+    def renderXML(self):
         return self.templateFunc(self.name, self.view, self.tid).read()
 
     def hookupCallbacks(self):
@@ -297,13 +312,16 @@ class UpdateRegion(UpdateRegionBase):
         self.view.removeViewChangeCallback(self.onChange)
 
 class ConfigUpdateRegion(UpdateRegionBase):
+    def __init__(self, anchorId, anchorType, templateFunc, parent):
+        UpdateRegionBase.__init__(self, anchorId, anchorType, templateFunc, parent)
+        self.name = "ConfigUpdateRegion"
     def hookupCallbacks(self):
         config.addChangeCallback(self.onChange)
 
     def onUnlink(self):
         config.removeChangeCallback(self.onChange)
 
-    def currentXML(self):
+    def renderXML(self):
         return self.templateFunc(self.tid).read()
 
 # Object representing a set of registrations for Javascript callbacks when
@@ -327,6 +345,7 @@ class Handle:
         self.triggerActionURLsOnLoad = []
         self.triggerActionURLsOnUnload = []
         self.onUnlink = onUnlink
+        self.htmlChanger = HTMLChangeOptimizer()
         
     def addTriggerActionURLOnLoad(self,url):
         self.triggerActionURLsOnLoad.append(str(url))
@@ -387,7 +406,7 @@ class Handle:
         ur = ConfigUpdateRegion(anchorId, anchorType, templateFunc, self)
         self.updateRegions.append(ur)
 
-    def unlinkTemplate(self):
+    def unlinkTemplate(self, top = True):
         # Stop delivering callbacks, allowing the handle to be released.
         self.domHandler = None
         try:
@@ -478,7 +497,7 @@ def fillAttr(_value, _localVars):
         else:
             match = resourcePattern.match(_value)
             if match:
-                return resource.url(match.group(1))
+                return resources.url(match.group(1))
             else:
                 return _value
 
