@@ -120,14 +120,14 @@ import stat
 # - id tags are inserted in appropriate places
 # - An empty span is always created after a repeatForView, so we can't
 #   use it inside of a table
+# - Currently, we're using the translate and name attributes found on
+#   this page to mark text for translation
+#   http://www.zope.org/DevHome/Wikis/DevSite/Projects/ComponentArchitecture/ZPTInternationalizationSupport
 
 # To Do:
 # - Take a lock around the entire database while template is being filled
 # - Improve error handling (currently some random exception is thrown if
 #   the template is poorly structured)
-# - Currently, we're using the translate and name attributes found on
-#   this page to mark text for translation, but they're unhandled.
-#   http://www.zope.org/DevHome/Wikis/DevSite/Projects/ComponentArchitecture/ZPTInternationalizationSupport
 #
 #    Eventually, we may add support for more attributes
 
@@ -149,9 +149,9 @@ def setResourcePath(path):
 #
 # Compile the template given in inFile to python code in outFile
 #
-def compileTemplate(inFile, top = True, onlyBody = False):
+def compileTemplate(inFile, *args, **kwargs):
     handle = MetaHandle()
-    tcc = TemplateContentCompiler(handle, inFile, onlyBody = onlyBody)
+    tcc = TemplateContentCompiler(handle, inFile, *args, **kwargs)
     p = sax.make_parser()
     p.setFeature(sax.handler.feature_external_ges, False)
     p.setContentHandler(tcc)
@@ -194,6 +194,8 @@ def compileAllTemplates(root):
     source = resource.path('templates')
     sourceTime = modifiedTime(source)
     dest = resource.path(os.path.join('..','portable','compiled_templates'))
+    if not os.path.isdir(dest):
+        os.makedirs(dest)
     destTime = modifiedTime(dest)
     compilerTime = os.stat(resource.path(os.path.join(
                             '..','portable','template_compiler.py'))).st_mtime
@@ -202,6 +204,8 @@ def compileAllTemplates(root):
 
 def compileTemplates(tpath = None):
     outdir = resource.path(os.path.join('..','portable','compiled_templates'))
+    if not os.path.isdir(outdir):
+        os.makedirs(outdir)
     indir = resource.path('templates')
     if tpath is not None:
         print "Compiling %s" % tpath
@@ -246,11 +250,14 @@ class TemplateError(Exception):
 ##
 # SAX version of templating code
 class TemplateContentCompiler(sax.handler.ContentHandler):
-    def __init__(self, handle, name, debug = False, onlyBody = False):
+    def __init__(self, handle, name, debug = False, onlyBody = False,
+            addIdToTopLevelElement=False):
         self.handle = handle
         self.debug = debug
         self.onlyBody = onlyBody
+        self.addIdToTopLevelElement = addIdToTopLevelElement
         self.name = name
+        self.isDynamic = False
 
     def getOperationList(self):
         return self.outputLists[0]
@@ -272,10 +279,10 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         fileobj.write('import sorts\n')
         fileobj.write('import indexes\n')
         fileobj.write('import filters\n')
-        fileobj.write('import resource\n')
+        fileobj.write('import resources\n')
         fileobj.write('import gtcache\n')
         fileobj.write('_ = gtcache.gettext\n')
-        fileobj.write('def fillTemplate(domHandler, dtvPlatform, eventCookie, bodyTagExtra, *args, **kargs):\n')
+        fileobj.write('def fillTemplate(templateState, domHandler, dtvPlatform, eventCookie, bodyTagExtra, *args, **kargs):\n')
         self.handle.render(fileobj)
         fileobj.write('\n\n    out = StringIO()\n')
         
@@ -300,6 +307,7 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         self.elementStack = []
         self.inInclude = False
         self.inRepeatView = False
+        self.inRepeatWithTemplate = False
         self.inUpdateView = False
         self.inConfigUpdate = False
         self.inReplace = False
@@ -307,10 +315,13 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         self.inExecOnUnload = False
         self.inExecOnLoad = False
         self.repeatDepth = 0
+        self.hotspotDepth = -1
+        self.hotspotTagName = ''
         self.replaceDepth = 0
         self.hiding = False
         self.hideDepth = []
         self.depth = 0
+        self.bodyDepth = None
         self.repeatName = ''
         self.started = not self.onlyBody
         self.outputLists = [[]]
@@ -330,6 +341,8 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
 
     def startElement(self,name, attrs):
         self.depth = self.depth + 1
+        if name == 'body':
+            self.bodyDepth = self.depth
 
         if (len(self.translateDepth) > 0 and
                                    self.depth == self.translateDepth[-1]+1):
@@ -355,7 +368,16 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
             pass
         elif 't:repeatForView' in attrs.keys():
             self.startRepeat(attrs['t:repeatForView'])
-            self.addElementStart(name, attrs, addId=True)
+            if not 't:repeatTemplate' in attrs.keys():
+                self.addElementStart(name, attrs, addId=True)
+                self.inRepeatWithTemplate = False
+            else:
+                name = attrs['t:repeatTemplate']
+                self.addFillTemplate(name, addIdToTopLevelElement=True)
+                # if t:repeatTemplate is set, there shouldn't be any children
+                # of this element.  Create a new outputList to check this.
+                self.outputLists.append([]) 
+                self.inRepeatWithTemplate = True
         elif 't:updateForView' in attrs.keys():
             self.startUpdate(attrs['t:updateForView'])
             self.addElementStart(name, attrs, addId=True)
@@ -431,6 +453,8 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
             self.handle.addTriggerActionURLOnLoad(attrs['url'])
         elif name == 't:triggerActionOnUnload':
             self.handle.addTriggerActionURLOnUnload(attrs['url'])
+        elif 't:hotspot' in attrs.keys():
+            self.addHotspot(name, attrs['t:hotspot'])
         else:
             self.addElementStart(name, attrs)
 
@@ -464,8 +488,15 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
             self.addText('</%s>'%name)
             self.inReplace = False
         elif self.inRepeatView and self.depth == self.repeatDepth:
-            self.addText('</%s>'%name)
-            self.endText()
+            if self.inRepeatWithTemplate:
+                self.endText()
+                nestedOutputs = self.outputLists.pop()
+                if nestedOutputs:
+                    m = "Elements with t:repeatTemplate, can't have children"
+                    raise ValueError(m)
+            else:
+                self.addText('</%s>'%name)
+                self.endText()
             repeatList = self.endRepeat()
             repeatId = generateId()
             self.addText('<span id="%s"/>'%quoteattr(repeatId))
@@ -488,6 +519,9 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
                                      self.depth == self.translateDepth[-1]):
             self.addTranslation()
             self.addText('</%s>'%name)
+        elif self.depth == self.hotspotDepth:
+            self.addText("</%s><!-- HOT SPOT END -->" % self.hotspotTagName)
+            self.hotspotDepth = -1
         elif name == 't:execOnUnload':
             self.inExecOnUnload = False
             self.handle.addExecOnUnload(self.code)
@@ -534,9 +568,13 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         f.close()
         self.addText(html)
 
-    def addFillTemplate(self, name):
+    def addFillTemplate(self, name, *args, **kwargs):
         print "  compiling '%s' subtemplate" % name
-        (tcc, handle) = compileTemplate(name, False, True)
+        (tcc, handle) = compileTemplate(name, onlyBody=True, *args, **kwargs)
+        if tcc.isDynamic:
+            self.isDynamic = True
+            if self.inUpdateView or self.inConfigUpdate or self.inRepeatView:
+                raise TemplateError, "Nested Dynamic tags"
         self.handle.addSubHandle(handle)
         self.addInstructions(tcc.getOperationList())
 
@@ -546,22 +584,31 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         self.addText('">')
 
     def startRepeat(self, name):
+        if self.inUpdateView or self.inConfigUpdate or self.inRepeatView:
+            raise TemplateError, "Nested Dynamic tags"
         self.endText()
         self.inRepeatView = True
+        self.isDynamic = True
         self.repeatDepth = self.depth
         self.repeatName = name
         self.outputLists.append([])
 
     def startUpdate(self, name):
+        if self.inUpdateView or self.inConfigUpdate or self.inRepeatView:
+            raise TemplateError, "Nested Dynamic tags"
         self.endText()
         self.inUpdateView = True
+        self.isDynamic = True
         self.repeatDepth = self.depth
         self.repeatName = name
         self.outputLists.append([])
 
     def startConfigUpdate(self):
+        if self.inUpdateView or self.inConfigUpdate or self.inRepeatView:
+            raise TemplateError, "Nested Dynamic tags"
         self.endText()
         self.inConfigUpdate = True
+        self.isDynamic = True
         self.repeatDepth = self.depth
         self.outputLists.append([])
 
@@ -596,13 +643,16 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         self.outputText.append( text)
 
     def addElementStart(self, name, attrs, addId=False):
+        if (self.bodyDepth is not None and self.depth == self.bodyDepth + 1
+                and self.addIdToTopLevelElement):
+            addId = True
         self.addText('<%s'%name)
         for key in attrs.keys():
             if (not (key.startswith('t:') or key.startswith('i18n:')) or
                     key == 't:contextMenu'):
                 self.addAttr(key,attrs[key])
         if name.lower() == 'body':
-	    self.addInstruction(genInsertBodyTagExtra, None)
+            self.addInstruction(genInsertBodyTagExtra, None)
         if addId:
             self.addIdAndClose()
         else:
@@ -622,33 +672,42 @@ class TemplateContentCompiler(sax.handler.ContentHandler):
         self.addInstruction(genUpdateHideOnView,(viewName, ifValue, attrs, nodeId))
 
     def addAttr(self, attr, value):
+        self.addText(' %s="' % attr)
+        self.addDynamicText(value)
+        self.addText('"')
+
+    def addDynamicText(self, value):
         match = attrPattern.match(value)
         if match:
-            self.addText(' %s="' % attr)
             while match:
                 self.addText(quoteattr(match.group(1)))
                 self.addInstruction(genQuoteAttr,match.group(2))
                 value = match.group(3)
                 match = attrPattern.match(value)
-            self.addText('%s"' % quoteattr(value))
+            self.addText('%s' % quoteattr(value))
         else:
             match = rawAttrPattern.match(value)
             if match:
-                self.addText(' %s="' % attr)
                 while match:
                     self.addText(quoteattr(match.group(1)))
                     self.addInstruction(genRawAttr,match.group(2))
                     value = match.group(3)
                     match = rawAttrPattern.match(value)
-                self.addText('%s"' % quoteattr(value))
+                self.addText('%s' % quoteattr(value))
             else:
-                self.addText(' %s="' % attr)
                 match = resourcePattern.match(value)
                 if match:
-                    self.addInstruction(genRepeatEval,'resource.url(%s)'%repr(match.group(1)))
+                    self.addInstruction(genRepeatEval,'resources.url(%s)'%repr(match.group(1)))
                 else:
                     self.addText(quoteattr(value))
-                self.addText('"')
+
+    def addHotspot(self, name, id):
+        self.hotspotDepth = self.depth
+        self.hotspotTagName = name
+        self.addText("<!-- HOT SPOT ")
+        self.addDynamicText(id)
+        self.addText(" -->")
+        self.addElementStart(name, {'id': id})
 
     def addEval(self,replace):
         self.addInstruction(genRepeatEval,replace)
@@ -751,10 +810,12 @@ class MetaHandle:
                 fileobj.write('%s    %s%s' % (prefix, line, ending))
         fileobj.write('%s# End user code%s%s' % (prefix, ending, ending))
 
+        fileobj.write('%slocalvars = locals()%s' % (prefix, ending))
+        fileobj.write('%slocalvars.update(globals())%s' % (prefix, ending))
         if self.execOnUnload is not None:
-            fileobj.write('%s%s = Handle(domHandler, locals(), onUnlink = _execOnUnload)%s%s' % (prefix, varname, ending, ending))
+            fileobj.write('%s%s = Handle(domHandler, localvars, onUnlink = _execOnUnload)%s%s' % (prefix, varname, ending, ending))
         else:
-            fileobj.write('%s%s = Handle(domHandler, locals(), onUnlink = lambda:None)%s%s' % (prefix, varname, ending, ending))
+            fileobj.write('%s%s = Handle(domHandler, localvars, onUnlink = lambda:None)%s%s' % (prefix, varname, ending, ending))
 
         count = 0
         for ur in self.updateRegions:
