@@ -232,12 +232,7 @@ class SortTestCase(DemocracyTestCase):
         self.higher = self.x
         self.sorted = self.everything.sort(self.sortFunc)
     def sortFunc(self,x,y):
-        if x is y:
-            return 0
-        elif x == self.higher:
-            return 1
-        else:
-            return -1
+        return x[1] != self.higher
     def testUnique(self):
         self.assertNotEqual(self.x,self.y)
     def testUniqueID(self):
@@ -488,14 +483,9 @@ class FilterSortMapTestCase(DemocracyTestCase):
     def filterFunc(self, x):
         return self.myfiltFunc(x)
     def sortFunc(self, x, y):
-        x = x.getID()
-        y = y.getID()
-        if x < y:
-            return -1
-        elif x > y:
-            return 1
-        else:
-            return 0
+        x = x[1].getID()
+        y = y[1].getID()
+        return x < y
     def call(self,obj, id):
         self.callbacks += 1
     def test(self):
@@ -648,30 +638,25 @@ class CursorTestCase(DemocracyTestCase):
     def setUp(self):
         DemocracyTestCase.setUp(self)
         self.everything = database.defaultDatabase
-	self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
-	self.objs = self.everything.filter(lambda x: True).map(self.mapToObject).sort(self.sortOldID)
+        self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
+        self.objs = self.everything.filter(lambda x: True).map(self.mapToObject).sort(self.sortOldID)
     def sortOldID(self,x,y):
-	if x.oldID > y.oldID:
-	    return 1
-	elif x.oldID < y.oldID:
-	    return -1
-	else:
-	    return 0
+        return x[1].oldID < y[1].oldID
     def mapToObject(self, obj):
-	temp = database.DDBObject(add = False)
-	temp.oldID = obj.getID()
-	return temp
+        temp = database.DDBObject(add = False)
+        temp.oldID = obj.getID()
+        return temp
     def test(self):
-	self.assertEqual(self.objs.len(),3)
-	self.assertEqual(self.objs.cur(),None)
-	self.objs.getNext()
-	self.objs.getNext()
-	self.objs.getNext()
-	self.assertEqual(self.objs.cur(),self.objs[2])
+        self.assertEqual(self.objs.len(),3)
+        self.assertEqual(self.objs.cur(),None)
+        self.objs.getNext()
+        self.objs.getNext()
+        self.objs.getNext()
+        self.assertEqual(self.objs.cur(),self.objs[2])
         self.origObjs[2].remove()
-	self.assertEqual(self.objs.cur(),self.objs[1])
-	self.objs.getPrev()
-	self.assertEqual(self.objs.cur(),self.objs[0])
+        self.assertEqual(self.objs.cur(),self.objs[1])
+        self.objs.getPrev()
+        self.assertEqual(self.objs.cur(),self.objs[0])
     def testStack(self):
         obj = self.everything.getNext()
         self.assertEqual(self.everything.cur(), obj)
@@ -685,40 +670,35 @@ class RecomputeMapTestCase(DemocracyTestCase):
     def setUp(self):
         DemocracyTestCase.setUp(self)
         self.everything = database.defaultDatabase
-	self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
-	self.objs = self.everything.filter(lambda x: True).map(self.mapToObject).sort(self.sortOldID).map(self.mapToObject)
-	self.changeCalls = 0
+        self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
+        self.objs = self.everything.filter(lambda x: True).map(self.mapToObject).sort(self.sortOldID).map(self.mapToObject)
+        self.changeCalls = 0
     def sortOldID(self,x,y):
-	if x.oldID > y.oldID:
-	    return 1
-	elif x.oldID < y.oldID:
-	    return -1
-	else:
-	    return 0
+        return x[1].oldID < y[1].oldID
     def mapToObject(self, obj):
-	temp = database.DDBObject(add = False)
-	temp.oldID = obj.getID()
-	return temp
+        temp = database.DDBObject(add = False)
+        temp.oldID = obj.getID()
+        return temp
     def changeCall(self,item,id):
-	self.changeCalls +=1
+        self.changeCalls +=1
     def test(self):
-	self.objs.addChangeCallback(self.changeCall)
-	self.everything.recomputeFilters()
-	self.everything.recomputeFilters()
-	temp = self.everything.getNext()
-	temp.signalChange()
-	self.assertEqual(self.changeCalls,1)
+        self.objs.addChangeCallback(self.changeCall)
+        self.everything.recomputeFilters()
+        self.everything.recomputeFilters()
+        temp = self.everything.getNext()
+        temp.signalChange()
+        self.assertEqual(self.changeCalls,1)
 
 class FilterUpdateOnChange(DemocracyTestCase):
     def setUp(self):
         DemocracyTestCase.setUp(self)
         self.everything = database.defaultDatabase
-	self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
+        self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
         self.origObjs[0].good = True
         self.origObjs[1].good = False
         self.origObjs[2].good = False
-	self.objs = self.everything.filter(lambda x: x.good)
-	self.changeCalls = 0
+        self.objs = self.everything.filter(lambda x: x.good)
+        self.changeCalls = 0
     def testLoss(self):
         self.assertEqual(self.objs.len(),1)
         self.origObjs[0].good = False
@@ -735,16 +715,16 @@ class MapUpdateOnChange(DemocracyTestCase):
     def setUp(self):
         DemocracyTestCase.setUp(self)
         self.everything = database.defaultDatabase
-	self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
+        self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
         self.origObjs[0].good = True
         self.origObjs[1].good = False
         self.origObjs[2].good = False
-	self.objs = self.everything.map(self.mapToObject).filter(lambda x: x.good)
-	self.changeCalls = 0
+        self.objs = self.everything.map(self.mapToObject).filter(lambda x: x.good)
+        self.changeCalls = 0
     def mapToObject(self, obj):
-	temp = database.DDBObject(add = False)
-	temp.good = obj.good
-	return temp
+        temp = database.DDBObject(add = False)
+        temp.good = obj.good
+        return temp
     def testLoss(self):
         self.assertEqual(self.objs.len(),1)
         self.origObjs[0].good = False
@@ -760,12 +740,12 @@ class SortUpdateOnChange(DemocracyTestCase):
     def setUp(self):
         DemocracyTestCase.setUp(self)
         self.everything = database.defaultDatabase
-	self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
+        self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
         self.origObjs[0].good = True
         self.origObjs[1].good = False
         self.origObjs[2].good = False
-	self.objs = self.everything.sort(lambda x, y: 0).sort(lambda x, y: 0).filter(lambda x: x.good)
-	self.changeCalls = 0
+        self.objs = self.everything.sort(lambda x, y: 0).sort(lambda x, y: 0).filter(lambda x: x.good)
+        self.changeCalls = 0
     def testLoss(self):
         self.assertEqual(self.objs.len(),1)
         self.origObjs[0].good = False
@@ -781,15 +761,10 @@ class IDBaseTraversal(DemocracyTestCase):
     def setUp(self):
         DemocracyTestCase.setUp(self)
         self.everything = database.defaultDatabase
-	self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
+        self.origObjs = [database.DDBObject(), database.DDBObject(), database.DDBObject()]
         self.sorted = self.everything.sort(self.sortID)
     def sortID(self,x,y):
-	if x.getID() > y.getID():
-	    return 1
-	elif x.getID() < y.getID():
-	    return -1
-	else:
-	    return 0
+        return x[1].getID() < y[1].getID()
     def test(self):
         self.assertEqual(self.origObjs[0],
                          self.sorted.getObjectByID(self.origObjs[0].getID()))
@@ -830,8 +805,8 @@ class IDBaseTraversal(DemocracyTestCase):
 #     def testAddRemove(self):
 #         self.add100()
 #         thread = Thread(target = self.add100)
-# 	thread.setDaemon(False)
-# 	thread.start()
+#         thread.setDaemon(False)
+#         thread.start()
 #         self.remove100()
 #         thread.join()
 
@@ -858,16 +833,11 @@ class IndexFilterTest(IndexFilterTestBase):
     def mod100(self, x):
         return (x.getID() + self.shift) % 100
     def sortIndexFunc(self, x, y):
-        return cmp(x.myValue, y.myValue)
+        return x[1].myValue < y[1].myValue
     def sortFunc(self, x, y):
-        x = x.getID()
-        y = y.getID()
-        if x < y:
-            return -1
-        elif x > y:
-            return 1
-        else:
-            return 0
+        x = x[1].getID()
+        y = y[1].getID()
+        return x < y
     def testBasicIndexFilter(self):
         for x in range(0,100):
             database.DDBObject()
@@ -1044,6 +1014,51 @@ class IndexFilterTest(IndexFilterTestBase):
                 self.assert_(last.myValue < obj.myValue)
             last = obj
 
+    def testChangeIndexValue(self):
+        for x in range(0,100):
+            database.DDBObject()
+        self.everything.createIndex(self.mod10, sortFunc=self.sortFunc)
+        filtered = self.everything.filterWithIndex(self.mod10,0)
+        filtered.addAddCallback(self.addCallback)
+        filtered.addRemoveCallback(self.removeCallback)
+        filtered.addChangeCallback(self.changeCallback)
+
+        filtered.changeIndexValue(self.mod10, 1)
+        self.assertEqual(filtered.len(),10)
+        self.assertEqual(self.addCallbacks,10)
+        self.assertEqual(self.removeCallbacks,10)
+        self.assertEqual(self.changeCallbacks,0)
+
+        filtered.resetCursor()
+        filtered3 = self.everything.filterWithIndex(self.mod10,0)
+        filtered2 = self.everything.filterWithIndex(self.mod10,1)
+        for obj in filtered2:
+            self.assertEqual(filtered.getNext().id, obj.id)
+            self.assertNotEqual(filtered3.getNext().id, obj.id)
+
+        for x in range(0,100):
+            database.DDBObject()
+        self.assertEqual(filtered.len(),20)
+        self.assertEqual(self.addCallbacks,20)
+
+        filtered.changeIndexValue(self.mod10, 0)
+        filtered.resetCursor()
+        filtered2.resetCursor()
+        filtered3.resetCursor()
+        for obj in filtered3:
+            self.assertEqual(filtered.getNext().id, obj.id)
+            self.assertNotEqual(filtered2.getNext().id, obj.id)
+        self.assertEqual(filtered.len(),20)
+        self.assertEqual(self.addCallbacks,40)
+        self.assertEqual(self.removeCallbacks,30)
+        self.assertEqual(self.changeCallbacks,0)
+        self.everything.removeView(filtered)
+        for x in range(0,100):
+            database.DDBObject()
+        self.assertEqual(self.addCallbacks,40)
+        self.assertEqual(self.removeCallbacks,30)
+        self.assertEqual(self.changeCallbacks,0)
+        
 class MultiIndexed(database.DDBObject):
     def __init__(self, indexValues):
         self.indexValues = indexValues
@@ -1141,7 +1156,7 @@ class ReSortTestCase(DemocracyTestCase):
         self.sorted.addChangeCallback(self.changeCall)
 
     def sortFunc(self, x, y):
-        return cmp(x.value,y.value)
+        return x[1].value < y[1].value
 
     def addCall(self, obj, id):
         # We have a convention of setting the cursor after the object
@@ -1185,7 +1200,7 @@ class SortingFilterTestCase(DemocracyTestCase):
 
     def sortFunc(self, x, y):
         self.sortCalls += 1
-        return cmp(x.value,y.value)
+        return x[1].value < y[1].value
 
     def testSort(self):
         sortView = self.everything.sort(self.sortFunc)
