@@ -146,6 +146,8 @@ def failed(when, withExn = False, details = None):
         header += "App:        %s\n" % config.get(prefs.LONG_APP_NAME)
         header += "Publisher:  %s\n" % config.get(prefs.PUBLISHER)
         header += "Platform:   %s\n" % config.get(prefs.APP_PLATFORM)
+        header += "Python:     %s\n" % sys.version
+        header += "Py Path:    %s\n" % repr(sys.path)
         header += "Version:    %s\n" % config.get(prefs.APP_VERSION)
         header += "Serial:     %s\n" % config.get(prefs.APP_SERIAL)
         header += "Revision:   %s\n" % config.get(prefs.APP_REVISION)
@@ -286,6 +288,11 @@ def trapCall(when, function, *args, **kwargs):
         failedExn(when)
         return False
 
+# Turn the next flag on to track the cumulative time for each when argument to
+# timeTrapCall().  Don't do this for production builds though!  Since we never
+# clean up the entries in the cumulative dict, turning this on amounts to a
+# memory leak.
+TRACK_CUMULATIVE = False 
 cumulative = {}
 cancel = False
 
@@ -300,18 +307,20 @@ def timeTrapCall(when, function, *args, **kwargs):
     if end-start > 0.5:
         print "WARNING: %s too slow (%.3f secs)" % (
             when, end-start)
-    try:
-        total = cumulative[when]
-    except KeyboardInterrupt:
-        raise
-    except:
-        total = 0
-    total += end - start
-    cumulative[when] = total
-    if total > 5.0:
-        print "WARNING: %s cumulative is too slow (%.3f secs)" % (
-            when, total)
-        cumulative[when] = 0
+    if TRACK_CUMULATIVE:
+        try:
+            total = cumulative[when]
+        except KeyboardInterrupt:
+            raise
+        except:
+            total = 0
+        total += end - start
+        cumulative[when] = total
+        return retval
+        if total > 5.0:
+            print "WARNING: %s cumulative is too slow (%.3f secs)" % (
+                when, total)
+            cumulative[when] = 0
     cancel = True
     return retval
 
@@ -390,6 +399,9 @@ def print_mem_usage(message):
 #    print message
 #    os.system ("ps huwwwp %d" % (os.getpid(),))
 
+class TooManySingletonsError(Exception):
+    pass
+
 def getSingletonDDBObject(view):
     view.confirmDBThread()
     viewLength = view.len()
