@@ -10,6 +10,15 @@ function getDTVPlatform() {
     return elt.getAttribute('dtvPlatform');
 }
 
+function loadURL(url) {
+    try {
+        document.location.href = url;
+    } catch (e) {
+        // This may happen if the backend decides to handle the url load
+        // itself.
+    }
+}
+
 // For calling from page Javascript: Cause a URL to be loaded. The
 // assumption is that the application will notice, abort the load, and
 // take some action based on the URL.
@@ -18,12 +27,7 @@ function eventURL(url) {
 	// Generic strategy: trigger a load, and hope the application
 	// catches it and cancels it without creating a race
 	// condition.
-        try {
-            document.location.href = url;
-        } catch (e) {
-            // This may happen if the backend decides to handle the url load
-            // itself.
-        }
+        loadURL(url)
     } else {
 	// OS X WebKit (KHTML) strategy: pass in an Objective C object
 	// through the window object and call a method on it.
@@ -33,17 +37,15 @@ function eventURL(url) {
     return false;
 }
 
-// Open email client with email about selected video
-// All parameters come in URL encoded
-function recommendItem(title, url, feedURL) {
-    var mailURL = 'http://www.videobomb.com/index/democracyemail?url=' + 
-                url + '&title=' + title;
-    try {
-        document.location.href = mailURL;
-    } catch (e) {
-        // The backend will handle the URL load and this sometimes leads to an
-        // exception here.
-    }
+function recommendItem(title, url) {
+    loadURL('http://www.videobomb.com/index/democracyemail?url=' + 
+            url + '&title=' + title);
+    return false;
+}
+
+function recommendChannel(title, url) {
+    loadURL('http://www.videobomb.com/democracy_channel/email_friend' +
+        '?url=' + url + '&title=' + title);
     return false;
 }
 
@@ -75,6 +77,14 @@ var editSearchOldValue = '';
 var editSearchTimer = null;
 var editSearchCallback = null;
 
+function onSearchFocus(obj){
+  if (!obj.searching){
+	obj.value="";
+	obj.searching = '1';
+  }
+  startEditSearch(obj, null);
+}
+
 function startEditSearch(obj, callback) {
   editSearchOldValue = obj.value;
 
@@ -222,10 +232,25 @@ function handleDblClick(event, viewName, id) {
    }
 }
 
+function getKeyFromEvent(evt) {
+  var key = 0;
+  if (window.event)  {
+    key = evt.keyCode;
+  } else if (evt.which) {
+  	key = evt.which;
+  }
+
+  return key;
+}
+
 function sendKeyToSearchBox(event) {
   if(event.altKey || event.ctrlKey || event.metaKey ||
       (event.target.tagName && event.target.tagName.toUpperCase() == 'INPUT'))
       return true;
+  var key = getKeyFromEvent(event);
+  if ((key == 33) || (key == 34) || (key == 35) || (key == 36) || 
+      (key == 37) || (key == 38) || (key == 39) || (key == 40))
+      return true;
   var searchBox = document.getElementById("search-box");
   searchBox.focus();
   return true;
